@@ -115,15 +115,15 @@ key_press (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
 {
     switch (event->keyval) {
 
-        case GDK_Escape:
+        case GDK_KEY_Escape:
             close_window (NULL, widget);
             return TRUE;
 
-        case GDK_Page_Down:
+        case GDK_KEY_Page_Down:
             about_switch_buttons (FALSE, appGUI);
             return TRUE;
 
-        case GDK_Page_Up:
+        case GDK_KEY_Page_Up:
             about_switch_buttons (TRUE, appGUI);
             return TRUE;
 
@@ -144,20 +144,20 @@ opt_create_about_window (GUI *appGUI)
     gtk_widget_set_events (window, GDK_BUTTON_PRESS_MASK | GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
     g_signal_connect (G_OBJECT (window), "key_press_event", G_CALLBACK (key_press), appGUI);
 
-    vbox_top = gtk_vbox_new (FALSE, VBOX_SPACING);
+    vbox_top = gtk_box_new (GTK_ORIENTATION_VERTICAL, VBOX_SPACING);
     gtk_container_add (GTK_CONTAINER (window), vbox_top);
 
     gui_create_about (vbox_top, appGUI);
 
     /* Close button */
-    hbuttonbox = gtk_hbutton_box_new ();
+    hbuttonbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
     gtk_box_pack_start (GTK_BOX (vbox_top), hbuttonbox, FALSE, TRUE, 0);
     gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
     gtk_box_set_spacing (GTK_BOX (hbuttonbox), HBOX_SPACING);
 
-    button_close = utl_gui_create_labeled_button (GTK_STOCK_CLOSE, OSMO_STOCK_BUTTON_CLOSE, _("Close"));
+    button_close = gtk_button_new_with_mnemonic(_("_Close"));
     gtk_container_add (GTK_CONTAINER (hbuttonbox), button_close);
-    GTK_WIDGET_SET_FLAGS (button_close, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (button_close, TRUE);
     g_signal_connect (G_OBJECT (button_close), "clicked", G_CALLBACK (close_window), window);
     gtk_widget_grab_focus (button_close);
 
@@ -284,7 +284,9 @@ const gchar *notes_editor_keys_text[] = {
         "Ctrl+u",                     N_("toggle underline"),
         "Ctrl+t",                     N_("toggle strikethrough"),
         "Ctrl+m",                     N_("toggle highlight"),
-        "Ctrl+n",                     N_("clear selection attributes")
+        "Ctrl+n",                     N_("clear selection attributes"),
+        "Ctrl+o",                     N_("open URLs"),
+        "Ctrl+.",                     N_("show document statistics")
     };
 #endif  /* NOTES_ENABLED */
 
@@ -477,10 +479,12 @@ display_about (GUI *appGUI)
                              NULL, OSMO_WEBSITE, TRUE, appGUI);
     gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, "\n", -1);
 
+#ifndef REPRODUCIBLE_BUILD
     str = g_strdup_printf ("\n(%s %s, %s)\n\n", _("compiled on"), __DATE__, __TIME__);
     gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer,
                                               &appGUI->about_entry_iter, str, -1, "center", "italic", NULL);
     g_free (str);
+#endif
 
     add_credits_section (_("Programming"), credits_programming, G_N_ELEMENTS (credits_programming), appGUI);
     add_credits_section (_("Graphics"), credits_graphics, G_N_ELEMENTS (credits_graphics), appGUI);
@@ -660,7 +664,7 @@ button_released_cb (GtkButton *button, GUI *appGUI)
 void
 gui_create_about (GtkWidget *vbox_top, GUI *appGUI)
 {
-    GtkWidget *hbox = NULL, *vbox = NULL;
+    GtkWidget *vbox = NULL;
     GtkWidget *label;
     GtkWidget *hseparator;
     GtkWidget *logo_area;
@@ -678,17 +682,18 @@ gui_create_about (GtkWidget *vbox_top, GUI *appGUI)
     gtk_widget_show (logo_area);
     gtk_box_pack_start (GTK_BOX (vbox_top), logo_area, FALSE, TRUE, 0);
 
-    if (appGUI->tiny_gui == TRUE) {
-        logo_scaled = gdk_pixbuf_scale_simple (logo,
-                                               gdk_pixbuf_get_width (logo) / 2,
-                                               gdk_pixbuf_get_height (logo) / 2,
-                                               GDK_INTERP_HYPER);
-    }
+/* 
+ * http://stackoverflow.com/questions/3781520/how-to-test-if-preprocessor-symbol-is-defined-but-has-no-value 
+ */
+#define DO_EXPAND(VAL)  VAL ## 1
+#define EXPAND(VAL)     DO_EXPAND(VAL)
 
-#ifndef REV
+#if (EXPAND(REPO) == 1)
     str = g_strdup_printf ("%s %s", _("version"), VERSION);
 #else
-    str = g_strdup_printf ("%s %d", _("SVN revision"), REV);
+    #define xstr(a) str(a)
+    #define str(a) #a
+    str = g_strdup_printf ("%s (%s)", _("GIT version"), xstr(REVISION));
 #endif
 
     label = gtk_label_new (str);
@@ -707,35 +712,26 @@ gui_create_about (GtkWidget *vbox_top, GUI *appGUI)
 
     /*--------------------------------------------------------------------------*/
 
-    vbox = gtk_vbox_new (FALSE, 4);
+    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 4);
     gtk_widget_show (vbox);
     gtk_box_pack_start (GTK_BOX (vbox_top), vbox, FALSE, TRUE, 0);
 
-    hseparator = gtk_hseparator_new ();
+    hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
     gtk_widget_show (hseparator);
     gtk_box_pack_start (GTK_BOX (vbox), hseparator, FALSE, TRUE, 0);
 
-    if (appGUI->tiny_gui == TRUE) {
-        hbox = gtk_hbox_new (FALSE, 0);
-        gtk_widget_show (hbox);
-        gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 0);
-    } else {
-        hbuttonbox = gtk_hbutton_box_new ();
-        gtk_widget_show (hbuttonbox);
-        gtk_box_pack_start (GTK_BOX (vbox), hbuttonbox, FALSE, TRUE, 0);
-        gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
-    }
+	hbuttonbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
+	gtk_widget_show (hbuttonbox);
+	gtk_box_pack_start (GTK_BOX (vbox), hbuttonbox, FALSE, TRUE, 0);
+	gtk_widget_set_halign(hbuttonbox, GTK_ALIGN_CENTER);
+	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
 
-    if (appGUI->tiny_gui == TRUE) {
-        appGUI->about_radiobutton = utl_gui_stock_label_radio_button (NULL, OSMO_STOCK_ABOUT, GTK_ICON_SIZE_LARGE_TOOLBAR);
-    } else {
-        appGUI->about_radiobutton = utl_gui_stock_label_radio_button (_("About"), OSMO_STOCK_ABOUT, GTK_ICON_SIZE_LARGE_TOOLBAR);
-        gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->about_radiobutton);
-    }
+	appGUI->about_radiobutton = utl_gui_icon_label_radio_button (_("About"), OSMO_STOCK_ABOUT, GTK_ICON_SIZE_LARGE_TOOLBAR);
+	gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->about_radiobutton);
     gtk_widget_show (appGUI->about_radiobutton);
 
     gtk_button_set_relief (GTK_BUTTON (appGUI->about_radiobutton), GTK_RELIEF_NONE);
-    GTK_WIDGET_UNSET_FLAGS (appGUI->about_radiobutton, GTK_CAN_FOCUS);
+    gtk_widget_set_can_focus (appGUI->about_radiobutton, FALSE);
     gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->about_radiobutton), radiobutton_group);
     radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->about_radiobutton));
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->about_radiobutton), TRUE);
@@ -744,15 +740,11 @@ gui_create_about (GtkWidget *vbox_top, GUI *appGUI)
     g_signal_connect (G_OBJECT (appGUI->about_radiobutton), "released",
                       G_CALLBACK (button_released_cb), appGUI);
 
-    if (appGUI->tiny_gui == TRUE) {
-        appGUI->help_radiobutton = utl_gui_stock_label_radio_button (NULL, OSMO_STOCK_HELP, GTK_ICON_SIZE_LARGE_TOOLBAR);
-    } else {
-        appGUI->help_radiobutton = utl_gui_stock_label_radio_button (_("Key shortcuts"), OSMO_STOCK_HELP, GTK_ICON_SIZE_LARGE_TOOLBAR);
-        gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->help_radiobutton);
-    }
+	appGUI->help_radiobutton = utl_gui_icon_label_radio_button (_("Key shortcuts"), OSMO_STOCK_HELP, GTK_ICON_SIZE_LARGE_TOOLBAR);
+	gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->help_radiobutton);
     gtk_widget_show (appGUI->help_radiobutton);
     gtk_button_set_relief (GTK_BUTTON (appGUI->help_radiobutton), GTK_RELIEF_NONE);
-    GTK_WIDGET_UNSET_FLAGS (appGUI->help_radiobutton, GTK_CAN_FOCUS);
+    gtk_widget_set_can_focus (appGUI->help_radiobutton, FALSE);
     gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->help_radiobutton), radiobutton_group);
     radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->help_radiobutton));
     gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (appGUI->help_radiobutton), FALSE);
@@ -760,15 +752,11 @@ gui_create_about (GtkWidget *vbox_top, GUI *appGUI)
     g_signal_connect (G_OBJECT (appGUI->help_radiobutton), "released",
                       G_CALLBACK (button_released_cb), appGUI);
 
-    if (appGUI->tiny_gui == TRUE) {
-        appGUI->license_radiobutton = utl_gui_stock_label_radio_button (NULL, OSMO_STOCK_LICENSE, GTK_ICON_SIZE_LARGE_TOOLBAR);
-    } else {
-        appGUI->license_radiobutton = utl_gui_stock_label_radio_button (_("License"), OSMO_STOCK_LICENSE, GTK_ICON_SIZE_LARGE_TOOLBAR);
-        gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->license_radiobutton);
-    }
+	appGUI->license_radiobutton = utl_gui_icon_label_radio_button (_("License"), OSMO_STOCK_LICENSE, GTK_ICON_SIZE_LARGE_TOOLBAR);
+	gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->license_radiobutton);
     gtk_widget_show (appGUI->license_radiobutton);
     gtk_button_set_relief (GTK_BUTTON (appGUI->license_radiobutton), GTK_RELIEF_NONE);
-    GTK_WIDGET_UNSET_FLAGS (appGUI->license_radiobutton, GTK_CAN_FOCUS);
+    gtk_widget_set_can_focus (appGUI->license_radiobutton, FALSE);
     gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->license_radiobutton), radiobutton_group);
     radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->license_radiobutton));
     gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (appGUI->license_radiobutton), FALSE);
@@ -776,13 +764,7 @@ gui_create_about (GtkWidget *vbox_top, GUI *appGUI)
     g_signal_connect (G_OBJECT (appGUI->license_radiobutton), "released",
                       G_CALLBACK (button_released_cb), appGUI);
 
-    if (appGUI->tiny_gui == TRUE) {
-        gtk_box_pack_end (GTK_BOX (hbox), appGUI->license_radiobutton, FALSE, TRUE, 0);
-        gtk_box_pack_end (GTK_BOX (hbox), appGUI->help_radiobutton, FALSE, TRUE, 0);
-        gtk_box_pack_end (GTK_BOX (hbox), appGUI->about_radiobutton, FALSE, TRUE, 0);
-    }
-
-    hseparator = gtk_hseparator_new ();
+    hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
     gtk_widget_show (hseparator);
     gtk_box_pack_start (GTK_BOX (vbox), hseparator, FALSE, TRUE, 0);
 
