@@ -156,10 +156,10 @@ notes_edit_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
 
     GUI *appGUI = (GUI *)data;
 
-    if (event->keyval == GDK_Escape) {
+    if (event->keyval == GDK_KEY_Escape) {
             notes_edit_close_cb (NULL, NULL, appGUI);
             return TRUE;
-    } else if (event->keyval == GDK_Return) {
+    } else if (event->keyval == GDK_KEY_Return) {
             notes_edit_action_cb (NULL, appGUI);
             return TRUE;
     }
@@ -190,7 +190,6 @@ notes_edit_dialog_show (GtkWidget *list, GtkTreeModel *model, GUI *appGUI)
 	GtkWidget *label;
 	GtkWidget *frame;
 	GtkWidget *table;
-	GtkWidget *alignment;
 
 	GtkTreeIter iter;
 	gchar *c_category, *category, *name;
@@ -212,50 +211,46 @@ notes_edit_dialog_show (GtkWidget *list, GtkTreeModel *model, GUI *appGUI)
 	g_signal_connect (G_OBJECT (appGUI->nte->edit_entry_window), "key_press_event",
 	                  G_CALLBACK (notes_edit_key_press_cb), appGUI);
 
-	vbox1 = gtk_vbox_new (FALSE, 0);
+	vbox1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_container_add (GTK_CONTAINER (appGUI->nte->edit_entry_window), vbox1);
 
-	table = gtk_table_new (1, 2, FALSE);
+	table = gtk_grid_new ();
 	gtk_box_pack_start (GTK_BOX (vbox1), table, FALSE, TRUE, 0);
 
 	frame = gtk_frame_new (NULL);
-	gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 0, 1,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
+        gtk_widget_set_hexpand(frame, TRUE);
+        gtk_widget_set_vexpand(frame, TRUE);
+	gtk_grid_attach (GTK_GRID (table), frame, 0, 0, 1, 1);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
-	alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-	gtk_container_add (GTK_CONTAINER (frame), alignment);
-	gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
-	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-
 	appGUI->nte->note_name_entry = gtk_entry_new ();
-	gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->note_name_entry);
+	gtk_container_add (GTK_CONTAINER (frame), appGUI->nte->note_name_entry);
+        gtk_widget_set_margin_left(appGUI->nte->note_name_entry, 16);
+        gtk_widget_set_margin_right(appGUI->nte->note_name_entry, 4);
+        gtk_widget_set_margin_top(appGUI->nte->note_name_entry, 4);
+        gtk_widget_set_margin_bottom(appGUI->nte->note_name_entry, 4);
 	gtk_entry_set_invisible_char (GTK_ENTRY (appGUI->nte->note_name_entry), 8226);
 	g_signal_connect (G_OBJECT (appGUI->nte->note_name_entry), "changed",
 	                  G_CALLBACK (notes_add_entry_changed_cb), appGUI);
 
-	sprintf (tmpbuf, "<b>%s:</b>", _("Note name"));
+	g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Note name"));
 	label = gtk_label_new (tmpbuf);
 	gtk_frame_set_label_widget (GTK_FRAME (frame), label);
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
 	frame = gtk_frame_new (NULL);
-	gtk_table_attach (GTK_TABLE (table), frame, 1, 2, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL),
-	                  (GtkAttachOptions) (GTK_FILL), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), frame, 1, 0, 1, 1);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
-	alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-	gtk_container_add (GTK_CONTAINER (frame), alignment);
-	gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
-	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
+	appGUI->nte->category_combobox = gtk_combo_box_text_new ();
+	gtk_container_add (GTK_CONTAINER (frame), appGUI->nte->category_combobox);
+        gtk_widget_set_margin_left(appGUI->nte->category_combobox, 16);
+        gtk_widget_set_margin_right(appGUI->nte->category_combobox, 4);
+        gtk_widget_set_margin_top(appGUI->nte->category_combobox, 4);
+        gtk_widget_set_margin_bottom(appGUI->nte->category_combobox, 4);
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (appGUI->nte->category_combobox), NULL, _("None"));
 
-	appGUI->nte->category_combobox = gtk_combo_box_new_text ();
-	gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->category_combobox);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->nte->category_combobox), _("None"));
-
-	sprintf (tmpbuf, "<b>%s:</b>", _("Category"));
+	g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Category"));
 	label = gtk_label_new (tmpbuf);
 	gtk_frame_set_label_widget (GTK_FRAME (frame), label);
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
@@ -264,36 +259,35 @@ notes_edit_dialog_show (GtkWidget *list, GtkTreeModel *model, GUI *appGUI)
 	gtk_box_pack_start (GTK_BOX (vbox1), frame, FALSE, FALSE, 0);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
-	alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-	gtk_container_add (GTK_CONTAINER (frame), alignment);
-	gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
-	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-
 	appGUI->nte->remember_cursor_checkbutton = gtk_check_button_new_with_mnemonic (_("Remember cursor position"));
-	GTK_WIDGET_UNSET_FLAGS (appGUI->nte->remember_cursor_checkbutton, GTK_CAN_FOCUS);
-	gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->remember_cursor_checkbutton);
+	gtk_container_add (GTK_CONTAINER (frame), appGUI->nte->remember_cursor_checkbutton);
+	gtk_widget_set_can_focus (appGUI->nte->remember_cursor_checkbutton, FALSE);
+        gtk_widget_set_margin_left(appGUI->nte->remember_cursor_checkbutton, 16);
+        gtk_widget_set_margin_right(appGUI->nte->remember_cursor_checkbutton, 4);
+        gtk_widget_set_margin_top(appGUI->nte->remember_cursor_checkbutton, 4);
+        gtk_widget_set_margin_bottom(appGUI->nte->remember_cursor_checkbutton, 4);
 
-	sprintf (tmpbuf, "<b>%s:</b>", _("Options"));
+	g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Options"));
 	label = gtk_label_new (tmpbuf);
 	gtk_frame_set_label_widget (GTK_FRAME (frame), label);
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-	hseparator = gtk_hseparator_new ();
+	hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, TRUE, 4);
 
-	hbuttonbox = gtk_hbutton_box_new ();
+	hbuttonbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox, FALSE, FALSE, 0);
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-	cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
-	GTK_WIDGET_UNSET_FLAGS (cancel_button, GTK_CAN_FOCUS);
+	cancel_button = gtk_button_new_with_mnemonic (_("_Cancel"));
+	gtk_widget_set_can_focus (cancel_button, FALSE);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
 	g_signal_connect (G_OBJECT (cancel_button), "clicked",
 	                  G_CALLBACK (button_notes_edit_close_cb), appGUI);
 
-	appGUI->nte->add_entry_ok_button = utl_gui_create_labeled_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
-	GTK_WIDGET_UNSET_FLAGS (appGUI->nte->add_entry_ok_button, GTK_CAN_FOCUS);
+	appGUI->nte->add_entry_ok_button = gtk_button_new_with_mnemonic (_("_OK"));
+	gtk_widget_set_can_focus (appGUI->nte->add_entry_ok_button, FALSE);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->nte->add_entry_ok_button);
 	g_signal_connect (G_OBJECT (appGUI->nte->add_entry_ok_button), "clicked",
 	                  G_CALLBACK (notes_edit_action_cb), appGUI);
@@ -310,7 +304,7 @@ notes_edit_dialog_show (GtkWidget *list, GtkTreeModel *model, GUI *appGUI)
 
 	while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, NULL, i++)) {
             gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, 0, &category, -1);
-            gtk_combo_box_append_text(GTK_COMBO_BOX(appGUI->nte->category_combobox), category);
+            gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(appGUI->nte->category_combobox), NULL, category);
             if (!strcmp(category, c_category)) n = i;
             g_free(category);
 	}
@@ -352,7 +346,7 @@ notes_remove_dialog_show (GUI *appGUI) {
     gchar tmpbuf[BUFFER_SIZE];
 
 
-    sprintf(tmpbuf, "%s\n%s\n\n%s", _("Selected note will be removed."),
+    g_snprintf(tmpbuf, BUFFER_SIZE, "%s\n%s\n\n%s", _("Selected note will be removed."),
             _("No further data recovery will be possible."), _("Are you sure?"));
 
     response = utl_gui_create_dialog(GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW(appGUI->main_window));
@@ -399,7 +393,7 @@ notes_add_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
 
     GUI *appGUI = (GUI *)data;
 
-    if (event->keyval == GDK_Escape) {
+    if (event->keyval == GDK_KEY_Escape) {
             notes_add_close_cb (NULL, NULL, appGUI);
             return TRUE;
     }
@@ -412,7 +406,7 @@ void
 notes_add_entry_action_cb (GtkWidget *widget, gpointer data) {
 
 gchar *name;
-gchar *empty_str, *current_filename;
+gchar *current_filename;
 gchar *category, *create_date_str;
 guint32 current_date;
 GtkTreeIter iter;
@@ -445,7 +439,6 @@ GRG_KEY keyholder;
 
     name = g_strdup(gtk_entry_get_text(GTK_ENTRY(appGUI->nte->note_name_entry)));
     n = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->nte->category_combobox));
-    empty_str = g_strdup("");
 	remember_cursor = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->nte->remember_cursor_checkbutton));
 
     notes_add_close_cb (NULL, NULL, appGUI);
@@ -467,16 +460,15 @@ GRG_KEY keyholder;
 
 		grg_encrypt_file (context, keyholder,
 		                  (unsigned char*) notes_get_full_filename (current_filename, appGUI),
-		                  (guchar *) empty_str, -1);
+		                  (guchar *)"", 0);
 
-		grg_free (context, empty_str, -1);
 		grg_key_free (context, keyholder);
 		grg_context_free (context);
 
 	} else {
 
 		g_file_set_contents (notes_get_full_filename(current_filename, appGUI), 
-							 (gchar *) empty_str, strlen(empty_str), NULL);
+							 "", 0, NULL);
 	}
 #endif /* HAVE_LIBGRINGOTTS */
 
@@ -543,7 +535,7 @@ notes_add_ok_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
 
     GUI *appGUI = (GUI *)data;
 
-    if (event->keyval == GDK_Return && notes_get_active_state (appGUI) == TRUE) {
+    if (event->keyval == GDK_KEY_Return && notes_get_active_state (appGUI) == TRUE) {
             notes_add_entry_action_cb (NULL, appGUI);
             return TRUE;
     }
@@ -580,7 +572,6 @@ GtkWidget *cancel_button;
 GtkWidget *label;
 GtkWidget *frame;
 GtkWidget *table;
-GtkWidget *alignment;
 
 #ifdef HAVE_LIBGRINGOTTS
 GtkWidget *hbox1;
@@ -609,35 +600,33 @@ GtkTreeIter iter;
     g_signal_connect (G_OBJECT (appGUI->nte->add_entry_window), "key_press_event",
                       G_CALLBACK (notes_add_key_press_cb), appGUI);
 
-    vbox1 = gtk_vbox_new (FALSE, 0);
+    vbox1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_widget_show (vbox1);
     gtk_container_add (GTK_CONTAINER (appGUI->nte->add_entry_window), vbox1);
 
-    table = gtk_table_new (1, 2, FALSE);
+    table = gtk_grid_new ();
     gtk_widget_show (table);
     gtk_box_pack_start (GTK_BOX (vbox1), table, FALSE, TRUE, 0);
 
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
-    gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 0, 1,
-                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
+    gtk_widget_set_hexpand(frame, TRUE);
+    gtk_widget_set_vexpand(frame, TRUE);
+    gtk_grid_attach (GTK_GRID (table), frame, 0, 0, 1, 1);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
-    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-    gtk_widget_show (alignment);
-    gtk_container_add (GTK_CONTAINER (frame), alignment);
-    gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-
     appGUI->nte->note_name_entry = gtk_entry_new ();
     gtk_widget_show (appGUI->nte->note_name_entry);
-    gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->note_name_entry);
+    gtk_container_add (GTK_CONTAINER (frame), appGUI->nte->note_name_entry);
+    gtk_widget_set_margin_left(appGUI->nte->note_name_entry, 16);
+    gtk_widget_set_margin_right(appGUI->nte->note_name_entry, 4);
+    gtk_widget_set_margin_top(appGUI->nte->note_name_entry, 4);
+    gtk_widget_set_margin_bottom(appGUI->nte->note_name_entry, 4);
     gtk_entry_set_invisible_char (GTK_ENTRY (appGUI->nte->note_name_entry), 8226);
     g_signal_connect (G_OBJECT (appGUI->nte->note_name_entry), "changed",
                       G_CALLBACK (notes_add_entry_changed_cb), appGUI);
 
-    sprintf (tmpbuf, "<b>%s:</b>", _("Note name"));
+    g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Note name"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
@@ -645,34 +634,30 @@ GtkTreeIter iter;
 
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
-    gtk_table_attach (GTK_TABLE (table), frame, 1, 2, 0, 1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (GTK_FILL), 0, 0);
+    gtk_grid_attach (GTK_GRID (table), frame, 1, 0, 1, 1);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
-    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-    gtk_widget_show (alignment);
-    gtk_container_add (GTK_CONTAINER (frame), alignment);
-    gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-
-    appGUI->nte->category_combobox = gtk_combo_box_new_text ();
+    appGUI->nte->category_combobox = gtk_combo_box_text_new ();
     gtk_widget_show (appGUI->nte->category_combobox);
-    gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->category_combobox);
-    gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->nte->category_combobox), _("None"));
+    gtk_container_add (GTK_CONTAINER (frame), appGUI->nte->category_combobox);
+    gtk_widget_set_margin_left(appGUI->nte->category_combobox, 16);
+    gtk_widget_set_margin_right(appGUI->nte->category_combobox, 4);
+    gtk_widget_set_margin_top(appGUI->nte->category_combobox, 4);
+    gtk_widget_set_margin_bottom(appGUI->nte->category_combobox, 4);
+    gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (appGUI->nte->category_combobox), NULL, _("None"));
 
     i = 0;
 
     while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, NULL, i++)) {
         gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, 0, &category, -1);
-        gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->nte->category_combobox), category);
+        gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (appGUI->nte->category_combobox), NULL, category);
         g_free(category);
     }
 
     gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->nte->category_combobox), 
                               gtk_combo_box_get_active (GTK_COMBO_BOX (appGUI->nte->cf_combobox)));
 
-    sprintf (tmpbuf, "<b>%s:</b>", _("Category"));
+    g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Category"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
@@ -685,33 +670,31 @@ GtkTreeIter iter;
     gtk_box_pack_start (GTK_BOX (vbox1), frame, FALSE, FALSE, 0);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
-	alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-	gtk_widget_show (alignment);
-	gtk_container_add (GTK_CONTAINER (frame), alignment);
-    gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
-	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-
-	hbox1 = gtk_hbox_new (FALSE, 0);
+	hbox1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_show (hbox1);
-	gtk_container_add (GTK_CONTAINER (alignment), hbox1);
+	gtk_container_add (GTK_CONTAINER (frame), hbox1);
+        gtk_widget_set_margin_left(hbox1, 16);
+        gtk_widget_set_margin_right(hbox1, 4);
+        gtk_widget_set_margin_top(hbox1, 4);
+        gtk_widget_set_margin_bottom(hbox1, 4);
 
 	appGUI->nte->note_normal_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("Plain"));
 	gtk_widget_show (appGUI->nte->note_normal_radiobutton);
     g_signal_connect (appGUI->nte->note_normal_radiobutton, "toggled", 
 					  G_CALLBACK (note_type_cb), appGUI);
-    GTK_WIDGET_UNSET_FLAGS(appGUI->nte->note_normal_radiobutton, GTK_CAN_FOCUS);
+    gtk_widget_set_can_focus(appGUI->nte->note_normal_radiobutton, FALSE);
 	gtk_box_pack_start (GTK_BOX (hbox1), appGUI->nte->note_normal_radiobutton, TRUE, TRUE, 0);
 	gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->nte->note_normal_radiobutton), note_normal_radiobutton_group);
 	note_normal_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->nte->note_normal_radiobutton));
 
 	note_encrypted_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("Encrypted"));
 	gtk_widget_show (note_encrypted_radiobutton);
-    GTK_WIDGET_UNSET_FLAGS(note_encrypted_radiobutton, GTK_CAN_FOCUS);
+    gtk_widget_set_can_focus(note_encrypted_radiobutton, FALSE);
 	gtk_box_pack_start (GTK_BOX (hbox1), note_encrypted_radiobutton, TRUE, TRUE, 0);
 	gtk_radio_button_set_group (GTK_RADIO_BUTTON (note_encrypted_radiobutton), note_normal_radiobutton_group);
 	note_normal_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (note_encrypted_radiobutton));
 
-    sprintf (tmpbuf, "<b>%s:</b>", _("Note type"));
+    g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Note type"));
 	label = gtk_label_new (tmpbuf);
 	gtk_widget_show (label);
 	gtk_frame_set_label_widget (GTK_FRAME (frame), label);
@@ -722,22 +705,20 @@ GtkTreeIter iter;
     gtk_box_pack_start (GTK_BOX (vbox1), frame, FALSE, FALSE, 0);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
-    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-    gtk_widget_show (alignment);
-    gtk_container_add (GTK_CONTAINER (frame), alignment);
-    gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-
     appGUI->nte->password_entry = gtk_entry_new ();
     gtk_widget_show (appGUI->nte->password_entry);
-    gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->password_entry);
+    gtk_container_add (GTK_CONTAINER (frame), appGUI->nte->password_entry);
+    gtk_widget_set_margin_left(appGUI->nte->password_entry, 16);
+    gtk_widget_set_margin_right(appGUI->nte->password_entry, 4);
+    gtk_widget_set_margin_top(appGUI->nte->password_entry, 4);
+    gtk_widget_set_margin_bottom(appGUI->nte->password_entry, 4);
     gtk_entry_set_invisible_char (GTK_ENTRY (appGUI->nte->password_entry), 8226);
     gtk_entry_set_visibility (GTK_ENTRY (appGUI->nte->password_entry), FALSE);
     g_signal_connect (G_OBJECT (appGUI->nte->password_entry), "changed",
                       G_CALLBACK (notes_add_entry_changed_cb), appGUI);
 	gtk_widget_set_sensitive (appGUI->nte->password_entry, FALSE);
 
-    sprintf (tmpbuf, "<b>%s:</b>", _("Enter password"));
+    g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Enter password"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
@@ -748,15 +729,13 @@ GtkTreeIter iter;
     gtk_box_pack_start (GTK_BOX (vbox1), frame, FALSE, FALSE, 0);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
-    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-    gtk_widget_show (alignment);
-    gtk_container_add (GTK_CONTAINER (frame), alignment);
-    gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-
     appGUI->nte->spassword_entry = gtk_entry_new ();
     gtk_widget_show (appGUI->nte->spassword_entry);
-    gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->spassword_entry);
+    gtk_container_add (GTK_CONTAINER (frame), appGUI->nte->spassword_entry);
+    gtk_widget_set_margin_left(appGUI->nte->spassword_entry, 16);
+    gtk_widget_set_margin_right(appGUI->nte->spassword_entry, 4);
+    gtk_widget_set_margin_top(appGUI->nte->spassword_entry, 4);
+    gtk_widget_set_margin_bottom(appGUI->nte->spassword_entry, 4);
     gtk_entry_set_invisible_char (GTK_ENTRY (appGUI->nte->spassword_entry), 8226);
     gtk_entry_set_visibility (GTK_ENTRY (appGUI->nte->spassword_entry), FALSE);
     g_signal_connect (G_OBJECT (appGUI->nte->spassword_entry), "changed",
@@ -765,7 +744,7 @@ GtkTreeIter iter;
                       G_CALLBACK (notes_add_ok_key_press_cb), appGUI);
 	gtk_widget_set_sensitive (appGUI->nte->spassword_entry, FALSE);
 
-    sprintf (tmpbuf, "<b>%s:</b>", _("Re-enter password"));
+    g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Re-enter password"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
@@ -778,42 +757,40 @@ GtkTreeIter iter;
     gtk_box_pack_start (GTK_BOX (vbox1), frame, FALSE, FALSE, 0);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
-    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-    gtk_widget_show (alignment);
-    gtk_container_add (GTK_CONTAINER (frame), alignment);
-    gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-
-	appGUI->nte->remember_cursor_checkbutton = gtk_check_button_new_with_mnemonic (_("Remember cursor position"));
-    GTK_WIDGET_UNSET_FLAGS(appGUI->nte->remember_cursor_checkbutton, GTK_CAN_FOCUS);
+    appGUI->nte->remember_cursor_checkbutton = gtk_check_button_new_with_mnemonic (_("Remember cursor position"));
+    gtk_widget_set_can_focus(appGUI->nte->remember_cursor_checkbutton, FALSE);
     gtk_widget_show (appGUI->nte->remember_cursor_checkbutton);
-    gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->remember_cursor_checkbutton);
+    gtk_container_add (GTK_CONTAINER (frame), appGUI->nte->remember_cursor_checkbutton);
+    gtk_widget_set_margin_left(appGUI->nte->remember_cursor_checkbutton, 16);
+    gtk_widget_set_margin_right(appGUI->nte->remember_cursor_checkbutton, 4);
+    gtk_widget_set_margin_top(appGUI->nte->remember_cursor_checkbutton, 4);
+    gtk_widget_set_margin_bottom(appGUI->nte->remember_cursor_checkbutton, 4);
 
-    sprintf (tmpbuf, "<b>%s:</b>", _("Options"));
+    g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Options"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-    hseparator = gtk_hseparator_new ();
+    hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
     gtk_widget_show (hseparator);
     gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, TRUE, 4);
 
-    hbuttonbox = gtk_hbutton_box_new ();
+    hbuttonbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
     gtk_widget_show (hbuttonbox);
     gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox, FALSE, FALSE, 0);
     gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
     gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-	cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
-    GTK_WIDGET_UNSET_FLAGS(cancel_button, GTK_CAN_FOCUS);
+	cancel_button = gtk_button_new_with_mnemonic (_("_Cancel"));
+    gtk_widget_set_can_focus(cancel_button, FALSE);
     gtk_widget_show (cancel_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
     g_signal_connect (G_OBJECT (cancel_button), "clicked",
                         G_CALLBACK (button_notes_add_close_cb), appGUI);
     
-    appGUI->nte->add_entry_ok_button = utl_gui_create_labeled_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
-    GTK_WIDGET_UNSET_FLAGS(appGUI->nte->add_entry_ok_button, GTK_CAN_FOCUS);
+    appGUI->nte->add_entry_ok_button = gtk_button_new_with_mnemonic (_("_OK"));
+    gtk_widget_set_can_focus(appGUI->nte->add_entry_ok_button, FALSE);
     gtk_widget_show (appGUI->nte->add_entry_ok_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->nte->add_entry_ok_button);
     g_signal_connect (G_OBJECT (appGUI->nte->add_entry_ok_button), "clicked",
@@ -938,10 +915,10 @@ notes_enter_password_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpoint
 
     GUI *appGUI = (GUI *)data;
 
-    if (event->keyval == GDK_Escape) {
+    if (event->keyval == GDK_KEY_Escape) {
             notes_enter_password_close_cb (NULL, NULL, appGUI);
             return TRUE;
-    } else if (event->keyval == GDK_Return) {
+    } else if (event->keyval == GDK_KEY_Return) {
             notes_enter_password_action_cb (NULL, appGUI);
             return TRUE;
     }
@@ -963,7 +940,6 @@ gchar *current_filename;
 
 #ifdef HAVE_LIBGRINGOTTS
 	GtkWidget *frame;
-	GtkWidget *alignment;
 	GtkWidget *ok_button;
 	GtkWidget *cancel_button;
 	GtkWidget *label;
@@ -1010,7 +986,7 @@ gchar *current_filename;
 			g_signal_connect (G_OBJECT (appGUI->nte->enter_password_window), "key_press_event",
 							  G_CALLBACK (notes_enter_password_key_press_cb), appGUI);
 
-			vbox1 = gtk_vbox_new (FALSE, 0);
+			vbox1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 			gtk_widget_show (vbox1);
 			gtk_container_add (GTK_CONTAINER (appGUI->nte->enter_password_window), vbox1);
 
@@ -1019,43 +995,41 @@ gchar *current_filename;
 			gtk_box_pack_start (GTK_BOX (vbox1), frame, FALSE, FALSE, 0);
 			gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
-			alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-			gtk_widget_show (alignment);
-			gtk_container_add (GTK_CONTAINER (frame), alignment);
-			gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
-			gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-
 			appGUI->nte->password_entry = gtk_entry_new ();
 			gtk_widget_show (appGUI->nte->password_entry);
-			gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->password_entry);
+			gtk_container_add (GTK_CONTAINER (frame), appGUI->nte->password_entry);
+                        gtk_widget_set_margin_left(appGUI->nte->password_entry, 16);
+                        gtk_widget_set_margin_right(appGUI->nte->password_entry, 4);
+                        gtk_widget_set_margin_top(appGUI->nte->password_entry, 4);
+                        gtk_widget_set_margin_bottom(appGUI->nte->password_entry, 4);
 			gtk_entry_set_invisible_char (GTK_ENTRY (appGUI->nte->password_entry), 8226);
 			gtk_entry_set_visibility (GTK_ENTRY (appGUI->nte->password_entry), FALSE);
 
-			sprintf (tmpbuf, "<b>%s:</b>", _("Enter password"));
+			g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Enter password"));
 			label = gtk_label_new (tmpbuf);
 			gtk_widget_show (label);
 			gtk_frame_set_label_widget (GTK_FRAME (frame), label);
 			gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-			hseparator = gtk_hseparator_new ();
+			hseparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
 			gtk_widget_show (hseparator);
 			gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, TRUE, 4);
 
-			hbuttonbox = gtk_hbutton_box_new ();
+			hbuttonbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
 			gtk_widget_show (hbuttonbox);
 			gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox, FALSE, FALSE, 0);
 			gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
 			gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-			cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
-			GTK_WIDGET_UNSET_FLAGS(cancel_button, GTK_CAN_FOCUS);
+			cancel_button = gtk_button_new_with_mnemonic (_("_Cancel"));
+			gtk_widget_set_can_focus(cancel_button, FALSE);
 			gtk_widget_show (cancel_button);
 			gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
 			g_signal_connect (G_OBJECT (cancel_button), "clicked",
 								G_CALLBACK (button_enter_password_close_cb), appGUI);
 			
-			ok_button = utl_gui_create_labeled_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
-			GTK_WIDGET_UNSET_FLAGS(ok_button, GTK_CAN_FOCUS);
+			ok_button = gtk_button_new_with_mnemonic (_("_OK"));
+			gtk_widget_set_can_focus(ok_button, FALSE);
 			gtk_widget_show (ok_button);
 			gtk_container_add (GTK_CONTAINER (hbuttonbox), ok_button);
 			g_signal_connect (G_OBJECT (ok_button), "clicked",
@@ -1089,16 +1063,16 @@ gint last_changes_time, create_time, editor_line;
 guint32 last_changes_date_julian, create_date_julian;
 gboolean remember_editor_line, editor_readonly;
 
-    notes_dir = g_strdup(prefs_get_config_filename(NOTES_DIRNAME, appGUI));
+    notes_dir = g_strdup(prefs_get_data_filename(NOTES_DIRNAME, appGUI));
     if (g_file_test (notes_dir, G_FILE_TEST_IS_DIR | G_FILE_TEST_EXISTS) == FALSE) {
         g_mkdir (notes_dir, 0755);
     }
     g_free(notes_dir);
 
-    if (g_file_test (prefs_get_config_filename(NOTES_ENTRIES_FILENAME, appGUI), G_FILE_TEST_IS_REGULAR) == FALSE) 
+    if (g_file_test (prefs_get_data_filename(NOTES_ENTRIES_FILENAME, appGUI), G_FILE_TEST_IS_REGULAR) == FALSE) 
         return;
 
-    if((doc = xmlParseFile(prefs_get_config_filename(NOTES_ENTRIES_FILENAME, appGUI)))) {
+    if((doc = xmlParseFile(prefs_get_data_filename(NOTES_ENTRIES_FILENAME, appGUI)))) {
 
         if(!(node = xmlDocGetRootElement(doc))) {
             xmlFreeDoc(doc);
@@ -1309,9 +1283,9 @@ xmlChar *escaped;
 
 		note_node = xmlNewChild (node, NULL, (const xmlChar *) "entry", (xmlChar *) NULL);
 
-		utl_xml_put_str ("name", name, note_node, doc);
+		utl_xml_put_str ("name", name, note_node);
 		g_free (name);
-		utl_xml_put_str ("category", category, note_node, doc);
+		utl_xml_put_str ("category", category, note_node);
 		g_free (category);
 		utl_xml_put_uint ("last_changes_date", last_changes_date_julian, note_node);
 		utl_xml_put_int ("last_changes_time", last_changes_time, note_node);
@@ -1320,12 +1294,12 @@ xmlChar *escaped;
 		utl_xml_put_int ("remember_editor_line", remember_editor_line, note_node);
 		utl_xml_put_int ("editor_line", editor_line, note_node);
 		utl_xml_put_int ("read_only", editor_readonly, note_node);
-		utl_xml_put_str ("fontname", note_fontname, note_node, doc);
-		utl_xml_put_str ("filename", note_filename, note_node, doc);
+		utl_xml_put_str ("fontname", note_fontname, note_node);
+		utl_xml_put_str ("filename", note_filename, note_node);
 		g_free (note_filename);
 	}
 
-	xmlSaveFormatFileEnc (prefs_get_config_filename (NOTES_ENTRIES_FILENAME, appGUI), doc, "utf-8", 1);
+	xmlSaveFormatFileEnc (prefs_get_data_filename (NOTES_ENTRIES_FILENAME, appGUI), doc, "utf-8", 1);
 	xmlFreeProp (attr);
 	xmlFreeDoc (doc);
 
@@ -1342,7 +1316,7 @@ static gchar fullpath[PATH_MAX];
 
     for(i=0; i < 99999999; i++) {
         g_snprintf(fullpath, PATH_MAX-1, "%s%c%08d.osm", 
-                   prefs_get_config_filename(NOTES_DIRNAME, appGUI), G_DIR_SEPARATOR, i);
+                   prefs_get_data_filename(NOTES_DIRNAME, appGUI), G_DIR_SEPARATOR, i);
         if (g_file_test (fullpath, G_FILE_TEST_EXISTS) == FALSE) break;
     }
 
@@ -1364,7 +1338,7 @@ const gchar *item_name;
 gchar *note_filename;
 GtkTreeIter iter;
 
-    g_snprintf(fullpath, PATH_MAX-1, "%s", prefs_get_config_filename(NOTES_DIRNAME, appGUI));
+    g_snprintf(fullpath, PATH_MAX-1, "%s", prefs_get_data_filename(NOTES_DIRNAME, appGUI));
     dpath = g_dir_open (fullpath, 0, NULL);
 
     if (dpath != NULL) {
@@ -1374,7 +1348,7 @@ GtkTreeIter iter;
             found = FALSE;
 
             g_snprintf(fullpath, PATH_MAX-1, "%s%c%s", 
-                       prefs_get_config_filename(NOTES_DIRNAME, appGUI), G_DIR_SEPARATOR, item_name);
+                       prefs_get_data_filename(NOTES_DIRNAME, appGUI), G_DIR_SEPARATOR, item_name);
 
             i = 0;
 
@@ -1412,7 +1386,7 @@ static gchar fullname[PATH_MAX];
 gchar *str;
 
     g_snprintf (fullname, PATH_MAX-1, "%s%c%s", 
-				prefs_get_config_filename(NOTES_DIRNAME, appGUI), G_DIR_SEPARATOR, filename);
+				prefs_get_data_filename(NOTES_DIRNAME, appGUI), G_DIR_SEPARATOR, filename);
 
 	if (g_file_test (fullname, G_FILE_TEST_IS_REGULAR | G_FILE_TEST_EXISTS) == FALSE) {
 
@@ -1420,7 +1394,7 @@ gchar *str;
 
 		if (str) {
 			g_snprintf (fullname, PATH_MAX-1, "%s%c%s", 
-						prefs_get_config_filename(NOTES_DIRNAME, appGUI), G_DIR_SEPARATOR, str);
+						prefs_get_data_filename(NOTES_DIRNAME, appGUI), G_DIR_SEPARATOR, str);
 			g_free (str);
 		}
 	}
