@@ -19,6 +19,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <errno.h>
+
 #include "options_prefs.h"
 #include "i18n.h"
 #include "utils.h"
@@ -32,52 +34,76 @@
 #include "calendar_utils.h"
 
 /*------------------------------------------------------------------------------*/
-
-gchar* 
-prefs_get_config_dir (GUI *appGUI) {
-
-static gchar dirname[PATH_MAX];
-
-    if (appGUI->config_path == NULL) {
-#if defined(CONFIG_PATH) && defined(CONFIG_DIR)
-        g_snprintf (dirname, PATH_MAX, "%s%c%s", CONFIG_PATH, G_DIR_SEPARATOR, CONFIG_DIR);
-#elif defined(CONFIG_DIR)
-        g_snprintf (dirname, PATH_MAX, "%s%c%s", g_get_home_dir(), G_DIR_SEPARATOR, CONFIG_DIR);
-#elif defined(CONFIG_PATH)
-        g_snprintf (dirname, PATH_MAX, "%s%c%s", CONFIG_PATH, G_DIR_SEPARATOR, CONFIG_DIRNAME);
-#else
-        g_snprintf (dirname, PATH_MAX, "%s%c%s", g_get_home_dir(), G_DIR_SEPARATOR, CONFIG_DIRNAME);
-#endif
-    } else {
-        g_strlcpy (dirname, appGUI->config_path, PATH_MAX);
-    }
-
-	return dirname;
+static gchar *
+build_app_specific_dir(const gchar *basedir) {
+    static gchar result[PATH_MAX];
+    gchar *dirname = g_build_filename(basedir, CONFIG_SUBDIR, NULL);
+    g_strlcpy(result, dirname, PATH_MAX);
+    g_free(dirname);
+    return result;
 }
 
+gchar *
+prefs_get_config_dir(GUI *appGUI) {
+    return (build_app_specific_dir(g_get_user_config_dir()));
+}
+
+gchar *
+prefs_get_data_dir(GUI *appGUI) {
+    return (build_app_specific_dir(g_get_user_data_dir()));
+}
 /*------------------------------------------------------------------------------*/
 
-gchar* 
-prefs_get_config_filename (gchar *config_filename, GUI *appGUI) {
+static gchar *
+get_filename(const gchar *filename, const gchar *basedir) {
+    static gchar result[PATH_MAX];
+    gchar *file, *dir;
+    struct stat st;
 
-static gchar filename[PATH_MAX];
-gchar *dirname = NULL;
-struct stat cfg;
+    g_return_val_if_fail(basedir != NULL, NULL);
+    file = g_build_filename(basedir, filename, NULL);
+    dir = g_path_get_dirname(file);
 
-	dirname = g_strdup (prefs_get_config_dir(appGUI));
-	g_return_val_if_fail (dirname != NULL, NULL);
+    if (g_stat(dir, &st) < 0) {
+        gint rc = g_mkdir_with_parents(dir, S_IRUSR | S_IWUSR | S_IXUSR);
+        if (rc) {
+            g_free(dir);
+            g_free(file);
+            return NULL;
+        }
+    }
 
-    if(g_stat (dirname, &cfg) < 0)
-        g_mkdir (dirname, S_IRUSR | S_IWUSR | S_IXUSR);
-
-    if (g_access (dirname, R_OK | W_OK) == -1) {
+    if (g_access(dir, R_OK | W_OK) == -1) {
+        g_free(dir);
+        g_free(file);
         return NULL;
     }
 
-    g_snprintf (filename, PATH_MAX, "%s%c%s", dirname, G_DIR_SEPARATOR, config_filename);
-	g_free (dirname);
+    g_strlcpy(result, file, PATH_MAX);
+    g_free(dir);
+    g_free(file);
 
-    return filename;
+    return result;
+}
+
+gchar *
+prefs_get_config_filename(gchar *filename, GUI *appGUI) {
+    return get_filename(filename, prefs_get_config_dir(appGUI));
+}
+
+gchar *
+prefs_get_data_filename(gchar *filename, GUI *appGUI) {
+    return get_filename(filename, prefs_get_data_dir(appGUI));
+}
+
+gchar*
+prefs_get_cache_filename(gchar *filename) {
+    return get_filename(filename, build_app_specific_dir(g_get_user_cache_dir()));
+}
+
+gchar*
+prefs_get_runtime_filename(gchar *filename, GUI *appGUI) {
+    return get_filename("lockfile", prefs_get_config_dir(appGUI));
 }
 
 /*------------------------------------------------------------------------------*/
@@ -90,23 +116,20 @@ gint i;
     /* general */
     config.window_x = 0;
     config.window_y = 0;
-    config.window_size_x = 540;
-    config.window_size_y = 690;
+    config.window_size_x = 950;
+    config.window_size_y = 560;
     config.fullscreen = 0;
     config.enable_tooltips = TRUE;
     config.latest_tab = 0;      /* calendar */
     config.tabs_position = GTK_POS_TOP;
     config.remember_latest_tab = TRUE;
     config.save_data_after_modification = TRUE;
-    config.default_stock_icons = FALSE;
     config.disable_underline_links = FALSE;
-    config.rules_hint = FALSE;
     config.toolbar_exit_button = FALSE;
     config.date_format = DATE_YYYY_MM_DD;
     config.time_format = TIME_24;
     config.enable_systray = TRUE;
     config.start_minimised_in_systray = FALSE;
-    config.blink_on_events = FALSE;
     config.ignore_day_note_events = FALSE;
     config.run_counter = 0;
     config.lastrun_date = utl_date_get_current_julian ();
@@ -116,7 +139,7 @@ gint i;
     config.hide_contacts = FALSE;
     config.hide_notes = FALSE;
     config.override_locale_settings = FALSE;
-    config.gui_layout = 0;      /* 0 - vertical, 1 - horizontal */
+    config.gui_layout = 1;      /* 0 - vertical, 1 - horizontal */
     config.sound_alarm_repeat = 1;
 	g_strlcpy (config.link_color, "blue", MAXCOLORNAME);
     g_strlcpy (config.spell_lang, g_getenv("LANG"), MAXNAME);
@@ -167,12 +190,16 @@ gint i;
     config.today_marker_type = TODAY_MARKER_FREEHAND_CIRCLE;
     config.day_notes_browser_filter = DN_FILTER_CURRENT_MONTH;
     config.ical_export_pane_pos = 180;
-	g_strlcpy (config.header_color, "#808080", MAXCOLORNAME);
+	g_strlcpy (config.background_color, "#FFFFFF", MAXCOLORNAME);
+	g_strlcpy (config.header_bg_color, "#404048", MAXCOLORNAME);
+	g_strlcpy (config.header_fg_color, "#DDDDDD", MAXCOLORNAME);
+	g_strlcpy (config.day_color, "#555555", MAXCOLORNAME);
+	g_strlcpy (config.pf_day_color, "#CCCCCC", MAXCOLORNAME);
 	g_strlcpy (config.weekend_color, "#880000", MAXCOLORNAME);
-	g_strlcpy (config.selection_color, "#526565", MAXCOLORNAME);
-	g_strlcpy (config.mark_color, "#dddddd", MAXCOLORNAME);
-	g_strlcpy (config.mark_current_day_color, "#34A434", MAXCOLORNAME);
-	g_strlcpy (config.birthday_mark_color, "#FFA500", MAXCOLORNAME);
+	g_strlcpy (config.selection_color, "#86ABD9", MAXCOLORNAME);
+	g_strlcpy (config.mark_color, "#CBE140", MAXCOLORNAME);
+	g_strlcpy (config.mark_current_day_color, "#E37751", MAXCOLORNAME);
+	g_strlcpy (config.birthday_mark_color, "#EDD400", MAXCOLORNAME);
     config.mark_current_day_alpha = 32768;
     config.selector_alpha = 32768;
 	g_strlcpy (config.day_name_font, "Sans Bold 20", MAXFONTNAME);
@@ -190,6 +217,7 @@ gint i;
 	config.cal_print_namedays = TRUE;
 	config.cal_print_day_notes = TRUE;
 	config.cal_print_ical = TRUE;
+	config.cal_print_disable_background	= FALSE;
 
     /* tasks */
     config.tasks_high_in_bold = TRUE;
@@ -358,15 +386,12 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("tabs_position", &config.tabs_position, general_node);
 					utl_xml_get_int ("remember_latest_tab", &config.remember_latest_tab, general_node);
 					utl_xml_get_int ("save_data_after_modification", &config.save_data_after_modification, general_node);
-					utl_xml_get_int ("default_stock_icons", &config.default_stock_icons, general_node);
 					utl_xml_get_int ("disable_underline_links", &config.disable_underline_links, general_node);
-					utl_xml_get_int ("rules_hint", &config.rules_hint, general_node);
 					utl_xml_get_int ("toolbar_exit_button", &config.toolbar_exit_button, general_node);
 					utl_xml_get_int ("date_format", &config.date_format, general_node);
 					utl_xml_get_int ("time_format", &config.time_format, general_node);
 					utl_xml_get_int ("enable_systray", &config.enable_systray, general_node);
 					utl_xml_get_int ("start_minimised_in_systray", &config.start_minimised_in_systray, general_node);
-					utl_xml_get_int ("blink_on_events", &config.blink_on_events, general_node);
 					utl_xml_get_int ("ignore_day_note_events", &config.ignore_day_note_events, general_node);
 					utl_xml_get_int ("run_counter", &config.run_counter, general_node);
 					utl_xml_get_int ("lastrun_date", &config.lastrun_date, general_node);
@@ -433,7 +458,11 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("today_marker_type", &config.today_marker_type, calendar_node);
 					utl_xml_get_int ("day_notes_browser_filter", &config.day_notes_browser_filter, calendar_node);
 					utl_xml_get_int ("ical_export_pane_pos", &config.ical_export_pane_pos, calendar_node);
-					utl_xml_get_strn ("header_color", config.header_color, MAXCOLORNAME, calendar_node);
+					utl_xml_get_strn ("background_color", config.background_color, MAXCOLORNAME, calendar_node);
+					utl_xml_get_strn ("header_bg_color", config.header_bg_color, MAXCOLORNAME, calendar_node);
+					utl_xml_get_strn ("header_fg_color", config.header_fg_color, MAXCOLORNAME, calendar_node);
+					utl_xml_get_strn ("day_color", config.day_color, MAXCOLORNAME, calendar_node);
+					utl_xml_get_strn ("pf_day_color", config.pf_day_color, MAXCOLORNAME, calendar_node);
 					utl_xml_get_strn ("weekend_color", config.weekend_color, MAXCOLORNAME, calendar_node);
 					utl_xml_get_strn ("selection_color", config.selection_color, MAXCOLORNAME, calendar_node);
 					utl_xml_get_strn ("mark_color", config.mark_color, MAXCOLORNAME, calendar_node);
@@ -456,6 +485,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("cal_print_namedays", &config.cal_print_namedays, calendar_node);
 					utl_xml_get_int ("cal_print_day_notes", &config.cal_print_day_notes, calendar_node);
 					utl_xml_get_int ("cal_print_ical", &config.cal_print_ical, calendar_node);
+					utl_xml_get_int ("cal_print_disable_background", &config.cal_print_disable_background, calendar_node);
 
 					calendar_node = calendar_node->next;
 				}
@@ -646,15 +676,12 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("tabs_position", config.tabs_position, general_node);
 	utl_xml_put_int ("remember_latest_tab", config.remember_latest_tab, general_node);
 	utl_xml_put_int ("save_data_after_modification", config.save_data_after_modification, general_node);
-	utl_xml_put_int ("default_stock_icons", config.default_stock_icons, general_node);
 	utl_xml_put_int ("disable_underline_links", config.disable_underline_links, general_node);
-	utl_xml_put_int ("rules_hint", config.rules_hint, general_node);
 	utl_xml_put_int ("toolbar_exit_button", config.toolbar_exit_button, general_node);
 	utl_xml_put_int ("date_format", config.date_format, general_node);
 	utl_xml_put_int ("time_format", config.time_format, general_node);
 	utl_xml_put_int ("enable_systray", config.enable_systray, general_node);
 	utl_xml_put_int ("start_minimised_in_systray", config.start_minimised_in_systray, general_node);
-	utl_xml_put_int ("blink_on_events", config.blink_on_events, general_node);
 	utl_xml_put_int ("ignore_day_note_events", config.ignore_day_note_events, general_node);
 	utl_xml_put_int ("run_counter", config.run_counter, general_node);
 	utl_xml_put_int ("lastrun_date", config.lastrun_date, general_node);
@@ -666,10 +693,10 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("override_locale_settings", config.override_locale_settings, general_node);
 	utl_xml_put_int ("gui_layout", config.gui_layout, general_node);
 	utl_xml_put_int ("sound_alarm_repeat", config.sound_alarm_repeat, general_node);
-	utl_xml_put_strn ("spell_lang", config.spell_lang, MAXNAME, general_node, doc);
-	utl_xml_put_strn ("web_browser", config.web_browser, MAXHELPERCMD, general_node, doc);
-	utl_xml_put_strn ("email_client", config.email_client, MAXHELPERCMD, general_node, doc);
-	utl_xml_put_strn ("sound_player", config.sound_player, MAXHELPERCMD, general_node, doc);
+	utl_xml_put_strn ("spell_lang", config.spell_lang, MAXNAME, general_node);
+	utl_xml_put_strn ("web_browser", config.web_browser, MAXHELPERCMD, general_node);
+	utl_xml_put_strn ("email_client", config.email_client, MAXHELPERCMD, general_node);
+	utl_xml_put_strn ("sound_player", config.sound_player, MAXHELPERCMD, general_node);
 
 	/*---------------------------------------------------------------------------------------*/
 	/* calendar */
@@ -709,27 +736,31 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("ascending_sorting_in_day_notes_browser", config.ascending_sorting_in_day_notes_browser, calendar_node);
 	utl_xml_put_int ("auxilary_calendars_state", config.auxilary_calendars_state, calendar_node);
 	utl_xml_put_int ("day_note_spell_checker", config.day_note_spell_checker, calendar_node);
-	utl_xml_put_strn ("day_note_marker", config.day_note_marker, MAXNAME, calendar_node, doc);
-	utl_xml_put_strn ("date_header_format", config.date_header_format, MAXNAME, calendar_node, doc);
+	utl_xml_put_strn ("day_note_marker", config.day_note_marker, MAXNAME, calendar_node);
+	utl_xml_put_strn ("date_header_format", config.date_header_format, MAXNAME, calendar_node);
 	utl_xml_put_int ("event_marker_type", config.event_marker_type, calendar_node);
 	utl_xml_put_int ("today_marker_type", config.today_marker_type, calendar_node);
 	utl_xml_put_int ("day_notes_browser_filter", config.day_notes_browser_filter, calendar_node);
 	utl_xml_put_int ("ical_export_pane_pos", config.ical_export_pane_pos, calendar_node);
-	utl_xml_put_strn ("header_color", config.header_color, MAXCOLORNAME, calendar_node, doc);
-	utl_xml_put_strn ("weekend_color", config.weekend_color, MAXCOLORNAME, calendar_node, doc);
-	utl_xml_put_strn ("selection_color", config.selection_color, MAXCOLORNAME, calendar_node, doc);
-	utl_xml_put_strn ("mark_color", config.mark_color, MAXCOLORNAME, calendar_node, doc);
-	utl_xml_put_strn ("mark_current_day_color", config.mark_current_day_color, MAXCOLORNAME, calendar_node, doc);
+	utl_xml_put_strn ("background_color", config.background_color, MAXCOLORNAME, calendar_node);
+	utl_xml_put_strn ("header_bg_color", config.header_bg_color, MAXCOLORNAME, calendar_node);
+	utl_xml_put_strn ("header_fg_color", config.header_fg_color, MAXCOLORNAME, calendar_node);
+	utl_xml_put_strn ("day_color", config.day_color, MAXCOLORNAME, calendar_node);
+	utl_xml_put_strn ("pf_day_color", config.pf_day_color, MAXCOLORNAME, calendar_node);
+	utl_xml_put_strn ("weekend_color", config.weekend_color, MAXCOLORNAME, calendar_node);
+	utl_xml_put_strn ("selection_color", config.selection_color, MAXCOLORNAME, calendar_node);
+	utl_xml_put_strn ("mark_color", config.mark_color, MAXCOLORNAME, calendar_node);
+	utl_xml_put_strn ("mark_current_day_color", config.mark_current_day_color, MAXCOLORNAME, calendar_node);
 	utl_xml_put_int ("mark_current_day_alpha", config.mark_current_day_alpha, calendar_node);
-	utl_xml_put_strn ("birthday_mark_color", config.birthday_mark_color, MAXCOLORNAME, calendar_node, doc);
+	utl_xml_put_strn ("birthday_mark_color", config.birthday_mark_color, MAXCOLORNAME, calendar_node);
 	utl_xml_put_int ("selector_alpha", config.selector_alpha, calendar_node);
-	utl_xml_put_strn ("day_name_font", config.day_name_font, MAXFONTNAME, calendar_node, doc);
-	utl_xml_put_strn ("calendar_font", config.calendar_font, MAXFONTNAME, calendar_node, doc);
-	utl_xml_put_strn ("notes_font", config.notes_font, MAXFONTNAME, calendar_node, doc);
-	utl_xml_put_strn ("cal_print_month_name_font", config.cal_print_month_name_font, MAXFONTNAME, calendar_node, doc);
-	utl_xml_put_strn ("cal_print_day_name_font", config.cal_print_day_name_font, MAXFONTNAME, calendar_node, doc);
-	utl_xml_put_strn ("cal_print_day_num_font", config.cal_print_day_num_font, MAXFONTNAME, calendar_node, doc);
-	utl_xml_put_strn ("cal_print_event_font", config.cal_print_event_font, MAXFONTNAME, calendar_node, doc);
+	utl_xml_put_strn ("day_name_font", config.day_name_font, MAXFONTNAME, calendar_node);
+	utl_xml_put_strn ("calendar_font", config.calendar_font, MAXFONTNAME, calendar_node);
+	utl_xml_put_strn ("notes_font", config.notes_font, MAXFONTNAME, calendar_node);
+	utl_xml_put_strn ("cal_print_month_name_font", config.cal_print_month_name_font, MAXFONTNAME, calendar_node);
+	utl_xml_put_strn ("cal_print_day_name_font", config.cal_print_day_name_font, MAXFONTNAME, calendar_node);
+	utl_xml_put_strn ("cal_print_day_num_font", config.cal_print_day_num_font, MAXFONTNAME, calendar_node);
+	utl_xml_put_strn ("cal_print_event_font", config.cal_print_event_font, MAXFONTNAME, calendar_node);
 	utl_xml_put_int ("cal_print_event_length", config.cal_print_event_length, calendar_node);
 	utl_xml_put_int ("cal_print_padding", config.cal_print_padding, calendar_node);
 	utl_xml_put_int ("cal_print_page_orientation", config.cal_print_page_orientation, calendar_node);
@@ -738,6 +769,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("cal_print_namedays", config.cal_print_namedays, calendar_node);
 	utl_xml_put_int ("cal_print_day_notes", config.cal_print_day_notes, calendar_node);
 	utl_xml_put_int ("cal_print_ical", config.cal_print_ical, calendar_node);
+	utl_xml_put_int ("cal_print_disable_background", config.cal_print_disable_background, calendar_node);
 
 	/*---------------------------------------------------------------------------------------*/
 	/* tasks */
@@ -775,11 +807,11 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("column_idx_4_width", config.tasks_column_idx_4_width, tasks_node);
 	utl_xml_put_int ("column_idx_5", config.tasks_column_idx_5, tasks_node);
 	utl_xml_put_int ("column_idx_5_width", config.tasks_column_idx_5_width, tasks_node);
-	utl_xml_put_strn ("due_today_color", config.due_today_color, MAXCOLORNAME, tasks_node, doc);
-	utl_xml_put_strn ("due_7days_color", config.due_7days_color, MAXCOLORNAME, tasks_node, doc);
-	utl_xml_put_strn ("past_due_color", config.past_due_color, MAXCOLORNAME, tasks_node, doc);
-	utl_xml_put_strn ("task_info_font", config.task_info_font, MAXFONTNAME, tasks_node, doc);
-	utl_xml_put_strn ("global_notification_command", config.global_notification_command, MAXHELPERCMD, tasks_node, doc);
+	utl_xml_put_strn ("due_today_color", config.due_today_color, MAXCOLORNAME, tasks_node);
+	utl_xml_put_strn ("due_7days_color", config.due_7days_color, MAXCOLORNAME, tasks_node);
+	utl_xml_put_strn ("past_due_color", config.past_due_color, MAXCOLORNAME, tasks_node);
+	utl_xml_put_strn ("task_info_font", config.task_info_font, MAXFONTNAME, tasks_node);
+	utl_xml_put_strn ("global_notification_command", config.global_notification_command, MAXHELPERCMD, tasks_node);
 
 	/*---------------------------------------------------------------------------------------*/
 	/* contacts */
@@ -795,12 +827,12 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("visible_age_column", config.cnt_visible_age_column, contacts_node);
 	utl_xml_put_int ("visible_birthday_date_column", config.cnt_visible_birthday_date_column, contacts_node);
 	utl_xml_put_int ("visible_zodiac_sign_column", config.cnt_visible_zodiac_sign_column, contacts_node);
-	utl_xml_put_strn ("contact_tag_color", config.contact_tag_color, MAXCOLORNAME, contacts_node, doc);
-	utl_xml_put_strn ("contact_link_color", config.contact_link_color, MAXCOLORNAME, contacts_node, doc);
+	utl_xml_put_strn ("contact_tag_color", config.contact_tag_color, MAXCOLORNAME, contacts_node);
+	utl_xml_put_strn ("contact_link_color", config.contact_link_color, MAXCOLORNAME, contacts_node);
 	utl_xml_put_int ("contact_name_font_size", config.contact_name_font_size, contacts_node);
 	utl_xml_put_int ("contact_item_font_size", config.contact_item_font_size, contacts_node);
 	utl_xml_put_int ("export_format", config.export_format, contacts_node);
-	utl_xml_put_strn ("export_fields", config.export_fields, MAXCONTACTFIELDS, contacts_node, doc);
+	utl_xml_put_strn ("export_fields", config.export_fields, MAXCONTACTFIELDS, contacts_node);
 	utl_xml_put_int ("contacts_sorting_order", config.contacts_sorting_order, contacts_node);
 	utl_xml_put_int ("contacts_sorting_column", config.contacts_sorting_column, contacts_node);
 	utl_xml_put_int ("contacts_addedit_win_x", config.contacts_addedit_win_x, contacts_node);
@@ -830,7 +862,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("import_bluetooth_channel", config.import_bluetooth_channel, contacts_node);
 	utl_xml_put_int ("import_usb_interface", config.import_usb_interface, contacts_node);
 	utl_xml_put_int ("import_binary_xml", config.import_binary_xml, contacts_node);
-	utl_xml_put_strn ("import_bluetooth_address", config.import_bluetooth_address, MAXADDRESS, contacts_node, doc);
+	utl_xml_put_strn ("import_bluetooth_address", config.import_bluetooth_address, MAXADDRESS, contacts_node);
 
 	/*---------------------------------------------------------------------------------------*/
 	/* notes */
@@ -861,15 +893,93 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("remember_category", config.remember_category_in_notes, notes_node);
 	utl_xml_put_int ("current_category", config.current_category_in_notes, notes_node);
 	utl_xml_put_int ("use_system_date", config.use_system_date_in_notes, notes_node);
-	utl_xml_put_char ("text_separator", config.text_separator, notes_node, doc);
-	utl_xml_put_strn ("editor_font", config.notes_editor_font, MAXFONTNAME, notes_node, doc);
+	utl_xml_put_char ("text_separator", config.text_separator, notes_node);
+	utl_xml_put_strn ("editor_font", config.notes_editor_font, MAXFONTNAME, notes_node);
 
 	/*---------------------------------------------------------------------------------------*/
 
 	xmlSaveFormatFile (prefs_get_config_filename (CONFIG_FILENAME, appGUI), doc, 1);
 	xmlFreeDoc (doc);
 }
+/*------------------------------------------------------------------------------*/
+static int
+copy(gchar *source, gchar *target) {
+    int source_fd, target_fd;
+    ssize_t len;
+    gchar buff[8192];
+    struct stat st;
+    mode_t perm;
 
+    if (stat(source, &st)) {
+        return -1;
+    }
+    perm = st.st_mode & (S_IRWXU | S_IRWXG | S_IRWXO);
+    source_fd = open(source, O_RDONLY);
+    if (source_fd == -1) {
+        return -1;
+    }
+    g_remove(target);
+    target_fd = open(target, O_WRONLY | O_CREAT | O_EXCL, perm);
+    if (target_fd == -1) {
+        close(source_fd);
+        return -1;
+    }
+
+    len = read(source_fd, buff, sizeof (buff));
+    while (len > 0) {
+        write(target_fd, buff, len);
+        len = read(source_fd, buff, sizeof (buff));
+    }
+    close(source_fd);
+    close(target_fd);
+
+    return 0;
+}
+
+static gboolean
+restore_from_dir(gchar *source_dirname, gchar *target_name, GUI *appGUI) {
+    GDir *source_dir = g_dir_open(source_dirname, 0, NULL);
+    if (source_dir) {
+        const gchar *old_name = g_dir_read_name(source_dir);
+        for (; old_name; old_name = g_dir_read_name(source_dir)) {
+            gchar *old_fullname = g_build_filename(source_dirname, old_name, NULL);
+
+            if (g_file_test(old_fullname, G_FILE_TEST_IS_REGULAR)) {
+                gchar *new_name = g_build_filename(target_name, old_name, NULL);
+                gboolean is_config = utl_text_strcmp(CONFIG_FILENAME, new_name) == 0;
+                gchar *new_fullname = is_config ? prefs_get_config_filename(new_name, appGUI) : prefs_get_data_filename(new_name, appGUI);
+                int rc = copy(old_fullname, new_fullname);
+                g_free(new_name);
+                if (rc == -1) {
+                    g_warning("Failed to move the old file %s to the new location %s. Aborting migration.", old_fullname, new_fullname);
+                    g_free(old_fullname);
+                    return FALSE;
+                }
+            } else if (g_file_test(old_fullname, G_FILE_TEST_IS_DIR)) {
+                gchar *new_target_name = g_build_filename(target_name, old_name, NULL);
+                gboolean rc = restore_from_dir(old_fullname, new_target_name, appGUI);
+                g_free(new_target_name);
+                if (rc == FALSE) {
+                    return FALSE;
+                }
+            } else {
+                g_warning("Do not know how to handle entry %s. Aborting migration.", old_fullname);
+                g_free(old_fullname);
+                return FALSE;
+            }
+
+            g_free(old_fullname);
+        }
+
+        g_dir_close(source_dir);
+    }
+    return TRUE;
+}
+
+gboolean
+prefs_restore (gchar *source_dir, GUI *appGUI) {
+    return restore_from_dir(source_dir, "", appGUI);
+}
 /*------------------------------------------------------------------------------*/
 
 
