@@ -52,15 +52,6 @@ checkbutton_clicked_cb (GtkToggleButton *togglebutton, gint *option)
 
 /* ========================================================================== */
 
-static void
-checkbutton_clicked_stock_icons_cb (GtkToggleButton *togglebutton, GUI *appGUI)
-{
-    config.default_stock_icons = gtk_toggle_button_get_active (togglebutton);
-	show_restart_info (appGUI);
-}
-
-/* ========================================================================== */
-
 static void
 layout_changed_cb (GtkComboBox *widget, GUI *appGUI)
 {
@@ -116,58 +107,38 @@ disable_underline_in_links_changed_cb (GtkToggleButton *togglebutton, GUI *appGU
 
 /* ========================================================================== */
 
-static void
-enable_rules_hint_changed_cb (GtkToggleButton *togglebutton, GUI *appGUI)
-{
-	config.rules_hint = gtk_toggle_button_get_active (togglebutton);
-
-#ifdef CONTACTS_ENABLED
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (appGUI->cnt->contacts_list), config.rules_hint);
-#endif /* CONTACTS_ENABLED */
-
-#ifdef NOTES_ENABLED
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (appGUI->nte->notes_list), config.rules_hint);
-#endif /* NOTES_ENABLED */
-
-#ifdef TASKS_ENABLED
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (appGUI->tsk->tasks_list), config.rules_hint);
-#endif /* TASKS_ENABLED */
-}
-
-/* ========================================================================== */
-
 static void
 toolbar_exit_button_changed_cb (GtkToggleButton *togglebutton, GUI *appGUI)
 {
 	config.toolbar_exit_button = gtk_toggle_button_get_active (togglebutton);
 
 	if (config.toolbar_exit_button == TRUE) {
-		gtk_widget_show (gtk_ui_manager_get_widget (appGUI->cal->calendar_uim_widget, "/toolbar/quit"));
+		gtk_widget_show (GTK_WIDGET(appGUI->cal->quit_button));
 	} else {
-		gtk_widget_hide (gtk_ui_manager_get_widget (appGUI->cal->calendar_uim_widget, "/toolbar/quit"));
+		gtk_widget_hide (GTK_WIDGET(appGUI->cal->quit_button));
 	}
 
 #ifdef CONTACTS_ENABLED
 	if (config.toolbar_exit_button == TRUE) {
-		gtk_widget_show (gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, "/toolbar/quit"));
+		gtk_widget_show (GTK_WIDGET(appGUI->cnt->quit_toolbar_button));
 	} else {
-		gtk_widget_hide (gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, "/toolbar/quit"));
+		gtk_widget_hide (GTK_WIDGET(appGUI->cnt->quit_toolbar_button));
 	}
 #endif /* CONTACTS_ENABLED */
 
 #ifdef NOTES_ENABLED
 	if (config.toolbar_exit_button == TRUE) {
-		gtk_widget_show (gtk_ui_manager_get_widget (appGUI->nte->notes_uim_selector_widget, "/toolbar/quit"));
+		gtk_widget_show (GTK_WIDGET(appGUI->nte->quit_button));
 	} else {
-		gtk_widget_hide (gtk_ui_manager_get_widget (appGUI->nte->notes_uim_selector_widget, "/toolbar/quit"));
+		gtk_widget_hide (GTK_WIDGET(appGUI->nte->quit_button));
 	}
 #endif /* NOTES_ENABLED */
 
 #ifdef TASKS_ENABLED
 	if (config.toolbar_exit_button == TRUE) {
-		gtk_widget_show (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/quit"));
+		gtk_widget_show (GTK_WIDGET(appGUI->tsk->quit_button));
 	} else {
-		gtk_widget_hide (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/quit"));
+		gtk_widget_hide (GTK_WIDGET(appGUI->tsk->quit_button));
 	}
 #endif /* TASKS_ENABLED */
 
@@ -180,59 +151,41 @@ create_appearance_section (GtkWidget *appearance_vbox, GUI *appGUI)
 {
 	GtkWidget *table, *label, *combobox, *checkbutton;
 
-	table = gtk_table_new (3, 4, FALSE);
+	table = gtk_grid_new ();
 	gtk_box_pack_start (GTK_BOX (appearance_vbox), table, FALSE, TRUE, 0);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 32);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 8);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 32);
+	gtk_grid_set_row_spacing (GTK_GRID (table), 8);
 
 	label = utl_gui_create_label ("%s:", _("Layout"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), label, 0, 0, 1, 1);
 
-	combobox = gtk_combo_box_new_text ();
-	gtk_table_attach (GTK_TABLE (table), combobox, 1, 2, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Vertical"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Horizontal"));
+	combobox = gtk_combo_box_text_new ();
+	gtk_grid_attach (GTK_GRID (table), combobox, 1, 0, 1, 1);
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, _("Vertical"));
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, _("Horizontal"));
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), config.gui_layout);
 	g_signal_connect (G_OBJECT (combobox), "changed", G_CALLBACK (layout_changed_cb), appGUI);
 
 	label = utl_gui_create_label ("%s:", _("Tabs position"));
-	gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), label, 2, 0, 1, 1);
 
-	combobox = gtk_combo_box_new_text ();
-	gtk_table_attach (GTK_TABLE (table), combobox, 3, 4, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Left"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Right"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Top"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Bottom"));
+	combobox = gtk_combo_box_text_new ();
+	gtk_grid_attach (GTK_GRID (table), combobox, 3, 0, 1, 1);
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, _("Left"));
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, _("Right"));
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, _("Top"));
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, _("Bottom"));
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), config.tabs_position);
 	g_signal_connect (G_OBJECT (combobox), "changed", G_CALLBACK (tabs_position_changed_cb), appGUI);
 
-	checkbutton = gtk_check_button_new_with_mnemonic (_("Use default stock icons"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.default_stock_icons);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 0, 2, 1, 2,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (checkbutton_clicked_stock_icons_cb), appGUI);
-
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Disable underline in links"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.disable_underline_links);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 0, 2, 2, 3,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 0, 1, 2, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (disable_underline_in_links_changed_cb), appGUI);
 
-	checkbutton = gtk_check_button_new_with_mnemonic (_("Draw rows in alternating colors"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.rules_hint);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 2, 4, 1, 2,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (enable_rules_hint_changed_cb), appGUI);
-
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Show exit button in toolbar"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.toolbar_exit_button);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 2, 4, 2, 3,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 2, 1, 2, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (toolbar_exit_button_changed_cb), appGUI);
 }
 
@@ -340,22 +293,22 @@ create_hide_section (GtkWidget *hide_vbox, GUI *appGUI)
 {
 	GtkWidget *table, *checkbutton;
 
-	table = gtk_table_new (1, 4, FALSE);
+	table = gtk_grid_new ();
 	gtk_box_pack_start (GTK_BOX (hide_vbox), table, TRUE, TRUE, 0);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 16);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 16);
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Calendar"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.hide_calendar);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 0, 1, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (GTK_FILL), 0, 0);
+        gtk_widget_set_hexpand(checkbutton, TRUE);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 0, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (hide_module_cb), appGUI);
 	appGUI->opt->hide_calendar_checkbutton = checkbutton;
 
 #ifdef TASKS_ENABLED
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Tasks"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.hide_tasks);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 1, 2, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (GTK_FILL), 0, 0);
+        gtk_widget_set_hexpand(checkbutton, TRUE);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 1, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (hide_module_cb), appGUI);
 	appGUI->opt->hide_tasks_checkbutton = checkbutton;
 #endif /* TASKS_ENABLED */
@@ -363,8 +316,8 @@ create_hide_section (GtkWidget *hide_vbox, GUI *appGUI)
 #ifdef CONTACTS_ENABLED
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Contacts"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.hide_contacts);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 2, 3, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (GTK_FILL), 0, 0);
+        gtk_widget_set_hexpand(checkbutton, TRUE);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 2, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (hide_module_cb), appGUI);
 	appGUI->opt->hide_contacts_checkbutton = checkbutton;
 #endif /* CONTACTS_ENABLED */
@@ -372,8 +325,8 @@ create_hide_section (GtkWidget *hide_vbox, GUI *appGUI)
 #ifdef NOTES_ENABLED
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Notes"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.hide_notes);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 3, 4, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (GTK_FILL), 0, 0);
+        gtk_widget_set_hexpand(checkbutton, TRUE);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 3, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (hide_module_cb), appGUI);
 	appGUI->opt->hide_notes_checkbutton = checkbutton;
 #endif /* NOTES_ENABLED */
@@ -474,51 +427,46 @@ create_general_section (GtkWidget *general_vbox, GUI *appGUI)
 	gchar *str;
 	gint i = 0;
 
-	table = gtk_table_new (6, 4, FALSE);
+	table = gtk_grid_new ();
 	gtk_box_pack_start (GTK_BOX (general_vbox), table, FALSE, FALSE, 0);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 16);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 4);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 16);
+	gtk_grid_set_row_spacing (GTK_GRID (table), 4);
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Override locale settings"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.override_locale_settings);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 0, 4, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 0, i, 4, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (override_locale_changed_cb), appGUI);
 	appGUI->opt->override_locale_checkbutton = checkbutton;
 
 	i++;
 
 	appGUI->opt->override_locale_label_1 = utl_gui_create_label ("%s:", _("Date format"));
-	gtk_table_attach (GTK_TABLE (table), appGUI->opt->override_locale_label_1, 0, 1, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), appGUI->opt->override_locale_label_1, 0, i, 1, 1);
 
-	combobox = gtk_combo_box_new_text ();
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("DD-MM-YYYY"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("MM-DD-YYYY"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("YYYY-MM-DD"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("YYYY-DD-MM"));
+	combobox = gtk_combo_box_text_new ();
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, _("DD-MM-YYYY"));
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, _("MM-DD-YYYY"));
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, _("YYYY-MM-DD"));
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, _("YYYY-DD-MM"));
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), config.date_format);
-	gtk_table_attach (GTK_TABLE (table), combobox, 1, 2, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), combobox, 1, i, 1, 1);
 	g_signal_connect (G_OBJECT (combobox), "changed", G_CALLBACK (date_format_changed_cb), appGUI);
 	appGUI->opt->date_format_combobox = combobox;
 
 	i++;
 
 	appGUI->opt->override_locale_label_2 = utl_gui_create_label ("%s:", _("Time format"));
-	gtk_table_attach (GTK_TABLE (table), appGUI->opt->override_locale_label_2, 0, 1, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), appGUI->opt->override_locale_label_2, 0, i, 1, 1);
 
-	combobox = gtk_combo_box_new_text ();
+	combobox = gtk_combo_box_text_new ();
 	str = g_strdup_printf ("24 %s", _("hours"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), str);
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, str);
 	g_free (str);
 	str = g_strdup_printf ("12 %s", _("hours"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), str);
+	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combobox), NULL, str);
 	g_free (str);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), config.time_format);
-	gtk_table_attach (GTK_TABLE (table), combobox, 1, 2, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), combobox, 1, i, 1, 1);
 	g_signal_connect (G_OBJECT (combobox), "changed", G_CALLBACK (time_format_changed_cb), appGUI);
 	appGUI->opt->time_format_combobox = combobox;
 
@@ -529,14 +477,12 @@ create_general_section (GtkWidget *general_vbox, GUI *appGUI)
 	GtkWidget *entry;
 
 	appGUI->opt->override_locale_label_3 = utl_gui_create_label ("%s:", _("Spell checker language"));
-	gtk_table_attach (GTK_TABLE (table), appGUI->opt->override_locale_label_3, 0, 1, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), appGUI->opt->override_locale_label_3, 0, i, 1, 1);
 
 	entry = gtk_entry_new ();
 	gtk_entry_set_max_length (GTK_ENTRY (entry), MAXNAME);
     gtk_entry_set_text (GTK_ENTRY (entry), config.spell_lang);
-	gtk_table_attach (GTK_TABLE (table), entry, 1, 2, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), entry, 1, i, 1, 1);
 	g_signal_connect (G_OBJECT (entry), "activate", G_CALLBACK (spell_checker_entry_changed_cb), appGUI);
 	g_signal_connect (G_OBJECT (entry), "key_press_event", G_CALLBACK (spell_checker_key_press_cb), appGUI);
 	appGUI->opt->entry_spell_lang = entry;
@@ -549,24 +495,21 @@ create_general_section (GtkWidget *general_vbox, GUI *appGUI)
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Enable tooltips"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.enable_tooltips);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 0, 4, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 0, i, 4, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (checkbutton_clicked_cb), &(config.enable_tooltips));
 
 	i++;
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Remember last selected page"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.remember_latest_tab);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 0, 4, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 0, i, 4, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (checkbutton_clicked_cb), &(config.remember_latest_tab));
 
 	i++;
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Save data after every modification"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.save_data_after_modification);
-	gtk_table_attach (GTK_TABLE (table), checkbutton, 0, 4, i, i+1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 0, i, 4, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (checkbutton_clicked_cb), &(config.save_data_after_modification));
 
 }
@@ -606,23 +549,21 @@ create_helpers_section (GtkWidget *helpers_vbox, GUI *appGUI)
 {
 	GtkWidget *table, *label, *entry;
 
-	table = gtk_table_new (3, 2, FALSE);
+	table = gtk_grid_new ();
 	gtk_box_pack_start (GTK_BOX (helpers_vbox), table, FALSE, FALSE, 0);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 8);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 8);
+	gtk_grid_set_row_spacing (GTK_GRID (table), 8);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 8);
 
 	label = utl_gui_create_label ("%s:", _("Web browser"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_grid_attach (GTK_GRID (table), label, 0, 0, 1, 1);
+        gtk_widget_set_valign(label, GTK_ALIGN_START);
+        gtk_widget_set_halign(label, GTK_ALIGN_CENTER);
 
 	label = utl_gui_create_label ("%s:", _("E-mail client"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), label, 0, 1, 1, 1);
 
 	label = utl_gui_create_label ("%s:", _("Sound player"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table), label, 0, 2, 1, 1);
 
 	entry = gtk_entry_new ();
 	gtk_entry_set_max_length (GTK_ENTRY (entry), MAXHELPERCMD);
@@ -630,8 +571,8 @@ create_helpers_section (GtkWidget *helpers_vbox, GUI *appGUI)
 	if (config.enable_tooltips) {
 		gtk_widget_set_tooltip_text (entry, _("The %s pattern will be replaced with web address"));
 	}
-	gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 0, 1,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(entry, TRUE);
+	gtk_grid_attach (GTK_GRID (table), entry, 1, 0, 1, 1);
 	g_signal_connect (G_OBJECT (entry), "activate", G_CALLBACK (helper_entry_changed_cb), appGUI);
 	g_signal_connect (G_OBJECT (entry), "key_press_event", G_CALLBACK (helper_key_press_cb), appGUI);
 	appGUI->opt->entry_web_browser = entry;
@@ -641,8 +582,8 @@ create_helpers_section (GtkWidget *helpers_vbox, GUI *appGUI)
 	gtk_entry_set_text (GTK_ENTRY (entry), config.email_client);
 	if (config.enable_tooltips)
 		gtk_widget_set_tooltip_text (entry, _("The %s pattern will be replaced with e-mail address"));
-	gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 1, 2,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(entry, TRUE);
+	gtk_grid_attach (GTK_GRID (table), entry, 1, 1, 1, 1);
 	g_signal_connect (G_OBJECT (entry), "activate", G_CALLBACK (helper_entry_changed_cb), appGUI);
 	g_signal_connect (G_OBJECT (entry), "key_press_event", G_CALLBACK (helper_key_press_cb), appGUI);
 	appGUI->opt->entry_email_client = entry;
@@ -652,8 +593,8 @@ create_helpers_section (GtkWidget *helpers_vbox, GUI *appGUI)
 	gtk_entry_set_text (GTK_ENTRY (entry), config.sound_player);
 	if (config.enable_tooltips)
 		gtk_widget_set_tooltip_text (entry, _("The %s pattern will be replaced with sound filename"));
-	gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 2, 3,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(entry, TRUE);
+	gtk_grid_attach (GTK_GRID (table), entry, 1, 2, 1, 1);
 	g_signal_connect (G_OBJECT (entry), "activate", G_CALLBACK (helper_entry_changed_cb), appGUI);
 	g_signal_connect (G_OBJECT (entry), "key_press_event", G_CALLBACK (helper_key_press_cb), appGUI);
 	appGUI->opt->entry_sound_player = entry;
@@ -667,13 +608,11 @@ enable_systray_changed_cb (GtkToggleButton *togglebutton, GUI *appGUI)
 	if (gtk_toggle_button_get_active (togglebutton)) {
 		config.enable_systray = 1;
 		gtk_widget_set_sensitive (appGUI->opt->start_minimised_checkbutton, TRUE);
-		gtk_widget_set_sensitive (appGUI->opt->blink_on_events_checkbutton, TRUE);
 		gtk_widget_set_sensitive (appGUI->opt->ignore_day_note_events_checkbutton, TRUE);
 		gtk_status_icon_set_visible (appGUI->osmo_trayicon, TRUE);
 	} else {
 		config.enable_systray = 0;
 		gtk_widget_set_sensitive (appGUI->opt->start_minimised_checkbutton, FALSE);
-		gtk_widget_set_sensitive (appGUI->opt->blink_on_events_checkbutton, FALSE);
 		gtk_widget_set_sensitive (appGUI->opt->ignore_day_note_events_checkbutton, FALSE);
 		gtk_status_icon_set_visible (appGUI->osmo_trayicon, FALSE);
 	}
@@ -686,36 +625,29 @@ create_system_tray_section (GtkWidget *system_tray_vbox, GUI *appGUI)
 {
 	GtkWidget *table, *checkbutton;
 
-	table = gtk_table_new (3, 3, FALSE);
+	table = gtk_grid_new ();
 	gtk_widget_show (table);
 	gtk_box_pack_start (GTK_BOX (system_tray_vbox), table, FALSE, FALSE, 0);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 4);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 4);
+	gtk_grid_set_column_spacing (GTK_GRID (table), 4);
+	gtk_grid_set_row_spacing (GTK_GRID (table), 4);
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Enable system tray"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.enable_systray);
-	gtk_table_attach_defaults (GTK_TABLE (table), checkbutton, 0, 1, 0, 1);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 0, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (enable_systray_changed_cb), appGUI);
 	appGUI->opt->enable_systray_checkbutton = checkbutton;
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Start minimised"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.start_minimised_in_systray);
 	gtk_widget_set_sensitive (checkbutton, config.enable_systray);
-	gtk_table_attach_defaults (GTK_TABLE (table), checkbutton, 1, 2, 0, 1);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 1, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (checkbutton_clicked_cb), &(config.start_minimised_in_systray));
 	appGUI->opt->start_minimised_checkbutton = checkbutton;
 
-	checkbutton = gtk_check_button_new_with_mnemonic (_("Blink on events"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.blink_on_events);
-	gtk_widget_set_sensitive (checkbutton, config.enable_systray);
-	gtk_table_attach_defaults (GTK_TABLE (table), checkbutton, 2, 3, 0, 1);
-	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (checkbutton_clicked_cb), &(config.blink_on_events));
-	appGUI->opt->blink_on_events_checkbutton = checkbutton;
-
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Ignore day note events"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.ignore_day_note_events);
 	gtk_widget_set_sensitive (checkbutton, config.enable_systray);
-	gtk_table_attach_defaults (GTK_TABLE (table), checkbutton, 0, 3, 1, 2);
+	gtk_grid_attach (GTK_GRID (table), checkbutton, 2, 0, 1, 1);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (checkbutton_clicked_cb), &(config.ignore_day_note_events));
 	appGUI->opt->ignore_day_note_events_checkbutton = checkbutton;
 }
@@ -727,7 +659,7 @@ create_general_page (GtkWidget *notebook, GUI *appGUI)
 {
 	GtkWidget *vbox_top, *vbox_icon, *vbox, *scrolledwindow;
 
-	vbox_top = gtk_vbox_new (FALSE, VBOX_SPACING);
+	vbox_top = gtk_box_new (GTK_ORIENTATION_VERTICAL, VBOX_SPACING);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox_top), BORDER_WIDTH);
 	scrolledwindow = utl_gui_insert_in_scrolled_window (vbox_top, GTK_SHADOW_ETCHED_IN);
 	gtk_container_set_border_width (GTK_CONTAINER (scrolledwindow), 2);
@@ -770,7 +702,7 @@ static gint
 key_press (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
 {
 	switch (event->keyval) {
-		case GDK_Escape:
+		case GDK_KEY_Escape:
 			close_window (NULL, widget);
 			return TRUE;
 	}
@@ -790,7 +722,7 @@ opt_create_preferences_window (GUI *appGUI)
 	window = utl_gui_create_window (_("Preferences"), 700, 600, appGUI);
 	g_signal_connect (G_OBJECT (window), "key_press_event", G_CALLBACK (key_press), appGUI);
 
-	vbox_top = gtk_vbox_new (FALSE, VBOX_SPACING);
+	vbox_top = gtk_box_new (GTK_ORIENTATION_VERTICAL, VBOX_SPACING);
 	gtk_container_add (GTK_CONTAINER (window), vbox_top);
 
 	appGUI->opt->notebook = notebook = gtk_notebook_new ();
@@ -822,14 +754,14 @@ opt_create_preferences_window (GUI *appGUI)
 #endif /* NOTES_ENABLED */
 
 	/* Close button */
-	hbuttonbox = gtk_hbutton_box_new ();
+	hbuttonbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start (GTK_BOX (vbox_top), hbuttonbox, FALSE, TRUE, 0);
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing (GTK_BOX (hbuttonbox), HBOX_SPACING);
 
-	close_button = utl_gui_create_labeled_button (GTK_STOCK_CLOSE, OSMO_STOCK_BUTTON_CLOSE, _("Close"));
+	close_button = gtk_button_new_with_mnemonic (_("_Close"));
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), close_button);
-	GTK_WIDGET_SET_FLAGS (close_button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (close_button, TRUE);
 	g_signal_connect (G_OBJECT (close_button), "clicked", G_CALLBACK (close_window), window);
 	gtk_widget_grab_focus (close_button);
 	gtk_widget_show_all (hbuttonbox);
