@@ -82,7 +82,7 @@ gint count, i;
 /*------------------------------------------------------------------------------*/
 
 gchar *     
-utl_inline_image_to_html (guint8 *inline_data)
+utl_inline_image_to_html (const guint8 *inline_data)
 {
 GdkPixbuf *image;
 gchar *output = g_strdup ("");
@@ -107,7 +107,7 @@ gchar tmpbuf[BUFFER_SIZE];
 /*------------------------------------------------------------------------------*/
 
 gchar *     
-utl_inline_to_png_base64 (guint8 *inline_data)
+utl_inline_to_png_base64 (const guint8 *inline_data)
 {
 GdkPixbuf *image;
 gchar *buffer, *output;
@@ -155,42 +155,41 @@ utl_text_match (const gchar *text, const gchar *regex) {
 #ifdef HAVE_LIBWEBKIT
 
 gboolean
-utl_webkit_console_msg (WebKitWebView *web_view,
-						gchar         *message,
-						gint           line,
-						gchar         *source_id,
-						gpointer       user_data) {
-	return TRUE; /* stop other handlers */
-}
-
-void
-utl_webkit_on_menu (WebKitWebView *view, GtkMenu *menu) {
+utl_webkit_on_menu (WebKitWebView       *web_view,
+               WebKitContextMenu   *context_menu,
+               GdkEvent            *event,
+               WebKitHitTestResult *hit_test_result,
+               gpointer             user_data) {
     /* don't show popup menus */
-    gtk_widget_destroy(GTK_WIDGET(menu));
+    return TRUE;
 }
 
-
 gboolean
-utl_webkit_link_clicked (WebKitWebView *view, WebKitWebFrame *frame,
-                         WebKitNetworkRequest *request, 
-                         WebKitWebNavigationAction *navigation_action,
-                         WebKitWebPolicyDecision *policy_decision) {
+utl_webkit_link_clicked(WebKitWebView *web_view,
+        WebKitPolicyDecision *decision,
+        WebKitPolicyDecisionType decision_type,
+        gpointer user_data) {
+    WebKitNavigationPolicyDecision *navigation_decision;
+    WebKitNavigationType navigation_type;
+    WebKitURIRequest *request;
+    const gchar *uri;
 
-const gchar *uri;
-WebKitWebNavigationReason reason;
 
-    g_return_val_if_fail (WEBKIT_IS_WEB_VIEW (view), FALSE);
-    g_return_val_if_fail (WEBKIT_IS_NETWORK_REQUEST (request), FALSE);
-
-    reason = webkit_web_navigation_action_get_reason (navigation_action);
-
-    if (reason != WEBKIT_WEB_NAVIGATION_REASON_LINK_CLICKED)
+    g_return_val_if_fail(WEBKIT_IS_WEB_VIEW(web_view), FALSE);
+    if (decision_type != WEBKIT_POLICY_DECISION_TYPE_NAVIGATION_ACTION) {
         return FALSE;
+    }
 
-    uri = webkit_network_request_get_uri (request);
-    webkit_web_policy_decision_ignore (policy_decision);
+    navigation_decision = WEBKIT_NAVIGATION_POLICY_DECISION(decision);
+    navigation_type = webkit_navigation_policy_decision_get_navigation_type(navigation_decision);
+    if (navigation_type != WEBKIT_NAVIGATION_TYPE_LINK_CLICKED) {
+        return FALSE;
+    }
+    request = webkit_navigation_policy_decision_get_request(navigation_decision);
+    uri = webkit_uri_request_get_uri(request);
+    webkit_policy_decision_ignore(decision);
 
-    utl_run_helper ((gchar *)uri, utl_get_link_type ((gchar *)uri));
+    utl_run_helper((gchar *) uri, utl_get_link_type((gchar *) uri));
 
     return FALSE;
 }
@@ -488,7 +487,7 @@ utl_subtract_from_date (guint32 date, gint time, gint days, gint seconds, guint3
     calculates the moon phase (0-7), accurate to 1 segment: 0 = > new moon, 4 => full moon.
 */
 
-guint
+gint
 utl_calc_moon_phase (const GDate *date)
 {
     gdouble jd;
@@ -677,7 +676,7 @@ gchar buffer[32];
 /*------------------------------------------------------------------------------*/
 
 void
-utl_xml_put_char (gchar *name, gchar character, xmlNodePtr node, xmlDocPtr doc)
+utl_xml_put_char (gchar *name, gchar character, xmlNodePtr node)
 {
     gchar buffer[32];
 
@@ -688,7 +687,7 @@ utl_xml_put_char (gchar *name, gchar character, xmlNodePtr node, xmlDocPtr doc)
 /*------------------------------------------------------------------------------*/
 
 void
-utl_xml_put_str (gchar *name, gchar *string, xmlNodePtr node, xmlDocPtr doc)
+utl_xml_put_str (gchar *name, gchar *string, xmlNodePtr node)
 {
     xmlNewTextChild (node, NULL, (const xmlChar *) name, (xmlChar *) string);
 }
@@ -696,7 +695,7 @@ utl_xml_put_str (gchar *name, gchar *string, xmlNodePtr node, xmlDocPtr doc)
 /*------------------------------------------------------------------------------*/
 
 void
-utl_xml_put_strn (gchar *name, gchar *string, gint buffer_size, xmlNodePtr node, xmlDocPtr doc)
+utl_xml_put_strn (gchar *name, gchar *string, gint buffer_size, xmlNodePtr node)
 {
     gchar buffer[BUFFER_SIZE];
 
@@ -751,14 +750,14 @@ utl_run_helper (gchar *parameter, gint helper) {
 gchar command[PATH_MAX], quoted[PATH_MAX];
 gboolean sync = FALSE;
 
-    sprintf (quoted, "\"%s\"", parameter);
+    g_snprintf(quoted, PATH_MAX, "\"%s\"", parameter);
 
     if (helper == EMAIL) {
-        sprintf (command, config.email_client, quoted);
+        g_snprintf(command, PATH_MAX, config.email_client, quoted);
     } else if (helper == WWW) {
-        sprintf (command, config.web_browser, quoted);
+        g_snprintf(command, PATH_MAX, config.web_browser, quoted);
     } else if (helper == SOUND) {
-        sprintf (command, config.sound_player, quoted);
+        g_snprintf(command, PATH_MAX, config.sound_player, quoted);
         sync = TRUE;
     } else {
         return FALSE;
@@ -796,17 +795,6 @@ utl_get_link_type (gchar *link)
 
 /*------------------------------------------------------------------------------*/
 
-void
-utl_cairo_set_color (cairo_t *cr, GdkColor *color, gint alpha)
-{
-    cairo_set_source_rgba (cr, (double) color->red / 65535.0,
-                               (double) color->green / 65535.0,
-                               (double) color->blue / 65535.0,
-                               (double) alpha / 65535.0);
-}
-
-/*------------------------------------------------------------------------------*/
-
 void
 utl_cairo_draw (cairo_t *cr, gint stroke)
 {
@@ -871,10 +859,14 @@ gint i;
 void
 utl_play_alarm_sound (guint repetitions)
 {
+    GThread *thread;
 	if (repetitions == 0)
 		return;
 
-    g_thread_try_new ("osmo", (GThreadFunc) utl_snd_play_thread, (gpointer) ((size_t) repetitions), NULL);
+    thread = g_thread_try_new ("osmo", (GThreadFunc) utl_snd_play_thread, (gpointer) ((size_t) repetitions), NULL);
+    if(thread) {
+        g_thread_unref(thread);
+    }
 }
 
 /*------------------------------------------------------------------------------*/
@@ -998,58 +990,63 @@ utl_free_list (GList *list, GDestroyNotify free_func) {
 }
 
 /*------------------------------------------------------------------------------*/
-
 #ifdef HAVE_LIBWEBKIT
-void
-utl_webkit_load_cb(WebKitWebView *view, GParamSpec *pspec, GUI *appGUI) {
-    WebKitLoadStatus load_status;
-    GtkAdjustment *scroll_adjustment;
-    g_object_get(view, "load-status", &load_status, NULL);
-    if (load_status == WEBKIT_LOAD_PROVISIONAL) {
-        scroll_adjustment = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(appGUI->cal->day_info_scrolledwindow));
-        appGUI->cal->html_scroll_position = gtk_adjustment_get_value(scroll_adjustment);
-    } else if (load_status == WEBKIT_LOAD_FINISHED) {
-        /* process pending events, wait till the end of drawing of the webview */
-        while (gtk_events_pending()) {
-            gtk_main_iteration();
-        }
-        scroll_adjustment = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(appGUI->cal->day_info_scrolledwindow));
-        gtk_adjustment_set_value(scroll_adjustment, appGUI->cal->html_scroll_position);
-    }
+WebKitWebView *
+utl_create_webkit_web_view() {
+    WebKitSettings *settings;
+    WebKitWebView *view;
+    settings = webkit_settings_new();
+
+    webkit_settings_set_enable_javascript(settings, FALSE);
+    webkit_settings_set_enable_plugins(settings, FALSE);
+    webkit_settings_set_enable_java(settings, FALSE);
+
+    view = WEBKIT_WEB_VIEW(webkit_web_view_new_with_settings(settings));
+    webkit_web_view_set_editable(view, FALSE);
+    return view;
 }
 #endif  /* HAVE_LIBWEBKIT */
 
 /*------------------------------------------------------------------------------*/
 
 gint
+/*utl_open_count_url_links (gchar *text, gint *tsize, gboolean url_count) {*/
 utl_open_count_url_links (gchar *text, gboolean url_count) {
 
-GRegex *regex;
-GMatchInfo *match_info;
+GRegex *regex = NULL;
+GMatchInfo *match_info = NULL;
 gchar url_path[PATH_MAX], command[PATH_MAX];
-gchar *URL;
-gint k = 0;
+gchar *URL = NULL, *qURL = NULL;
+gint k = 0, tsize;
 
 	regex = g_regex_new (REGEX_URL, 0, 0, NULL);
 	g_regex_match (regex, text, 0, &match_info);
 
     url_path[0] = '\0';
+	tsize = strlen(config.web_browser);
 
 	while (g_match_info_matches (match_info)) {
 
+	  	URL = g_match_info_fetch (match_info, 0);
+		qURL = g_shell_quote (URL);
 		if (url_count == FALSE) {
-	  		URL = g_match_info_fetch (match_info, 0);
-            strcat (url_path, "\"");
-            strcat (url_path, URL);
-            strcat (url_path, "\" ");
-			g_free (URL);
-		} 
-		k++;
+			if (tsize + strlen(qURL) < PATH_MAX) {
+				tsize += strlen(qURL) + 1 /* space */;
+				strcat (url_path, qURL);
+				strcat (url_path, " ");
+				k++;
+			}
+		} else {
+			tsize += strlen(qURL) + 1 /* space */;
+			k++;
+		}
+		g_free (qURL);
+		g_free (URL);
 		g_match_info_next (match_info, NULL);
 	}
 	
 	if (url_count == FALSE) {
-        sprintf (command, config.web_browser, url_path);
+        g_snprintf(command, PATH_MAX, config.web_browser, url_path);
         utl_run_command (command, FALSE);
     }
 
